@@ -1,12 +1,21 @@
 <html>
 <head>
 <title>dqqnqI</title>
-<meta http-equiv="Content-Type" content="text/html; charset=sjis">
+<meta http-equiv="Content-Type" content="text/html;charset=sjis">
 </head>
 
 <?cs if:Flag ?>
+
+<?cs if:IsMobile ?>
+
+<body>
+<b><?cs var:html_escape(LongErrorStr) ?></b>
+<p><a href="<?cs if:KEY ?><?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/i<?cs else ?><?cs var:html_escape(BBSURI) ?>/i/<?cs /if ?>">[h</a></p>
+
+<?cs else ?>
+
 <body bgcolor="#FFFFFF">
-<!-- 2ch_X:error --><!--nobanner-->
+<!-- 2ch_X:error -->
 <font size=+1 color=#FF0000><b>dqqnqF<?cs var:LongErrorStr ?></b></font>
 <ul>
 <br>
@@ -17,13 +26,15 @@ eF<br><?cs var:Message ?><br><br>
 </ul>
 <small>
 [h͂ōs܂B
-<a href="<?cs var:BBSURI ?>"> GO! </a>
+<a href="<?cs var:html_escape(BBSURI) ?>"> GO! </a>
 <hr>
 <div align=right><?cs var:html_escape(VERSION) ?></div>
 </small>
 
+<?cs /if ?>
+
 <?cs else ?>
-<!--nobanner-->
+
 <body bgcolor="#efefef">
 <b><font color=red face="Century Gothic" size=+2>ERROR!!</font>
 <font face="MS UI Gothic" size=+2> <?cs var:html_escape(Subject) ?></b></font>
@@ -41,6 +52,7 @@ eF<br><?cs var:Message ?><br><br>
 </td>
 </tr>
 </table>
+
 <?cs /if ?>
 
 </body></html>
