@@ -1,16 +1,13 @@
 <html>
 <head>
-<!--nobanner-->
 <title><?cs var:html_escape(BBS_TITLE) ?></title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 
-<!--meta.txto͕-->
-<?cs var:html_escape(MetaText) ?>
+<?cs var:MetaText ?>
 </head>
 
-<!--G[-->
 <?cs if:IsError ?>
 <body bgcolor=#efefef><b><font color=red face="Century Gothic" size=+2>ERROR!!</font>
 <font face="MS UI Gothic" size=+2><?cs var:html_escape(ShortErrorStr) ?></b></font><hr>
@@ -18,64 +15,54 @@
 <hr><table border=0 width=100%>
 <td align=right><b><small><?cs var:html_escape(VERSION) ?></small></b></td></tr></table>
 
-<!--v[ĂXbh𔭌-->
 <?cs else ?>
 <?cs if:IsPooled ?>
 <body bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>">
 
-<!--L\-->
-<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><hr><?cs /if ?>
+<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>
 
-<!--߂̃No͕-->
 <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
 <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
 <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
 <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a><br><br>
-<dl>
 
-<!--Xbh̃^Cgo͕-->
 <hr>
 <center><font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1">@̃Xbh͉ߋOqɂɊi[Ă܂B</font></center>
 <hr>
 
-<!--Xo͕-->
 <font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"><?cs var:Subject ?></font>
 <dl>
 <?cs each:item = Thread ?>
-<dt><?cs var:html_escape(item.resno) ?>OF<b><?cs if:item.mail ?><a href="<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><?cs var:item.name ?><?cs /if ?></b>F<?cs var:html_escape(item.date) ?></dt><dd id="r<?cs var:html_escape(item.resno) ?>"><?cs var:item.text ?><br><br></dd>
+<dt><?cs var:html_escape(item.resno) ?>
+OF<b><?cs if:item.mail ?><a href="<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><?cs var:item.name ?><?cs /if ?></b>F<?cs var:html_escape(item.date) ?></dt><dd id="r<?cs var:html_escape(item.resno) ?>"><?cs var:item.text ?><br><br></dd>
 <?cs /each ?>
 </dl>
 
-<!--dat̑傫\-->
 <font color=navy size=-1>X <b><?cs var:html_escape(ResCount) ?></b></font><br>
 <font color=red face="Arial"><b><?cs var:html_escape(DatKByteSize) ?>KB</b></font>
 
 <?cs if:IsArchived ?>
-<br><br>IߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token)1 ?>/<?cs var:html_escape(Token)2 ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a><br>𔭌܂I<br>
+<br><br>IߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a><br>𔭌܂I<br>
 <?cs /if ?>
 
 <hr><div align="right"><?cs var:html_escape(VERSION) ?></div>
 
-<!--Ȃ-->
 <?cs else ?>
 <body bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>">
 <font color=#ff0000 size=+1>ȔorXbhȂł</font><br>
 <dl><dt>1 OF<font color=green><b><?cs var:html_escape(VERSION) ?></b></font> eF<br>
 <dd>ȔorXbhȂł</dd></dt></dl><br><br><br><hr>
 
-<!--L̕\-->
-<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><?cs /if ?>
+<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><?cs /if ?>
 
-<!--ߋOĂ邩-->
 <?cs if:IsArchived ?>
-<br><br>IߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token)1 ?>/<?cs var:html_escape(Token)2 ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a><br>𔭌܂I<br>
+<br><br>IߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a><br>𔭌܂I<br>
 <?cs else ?>
 <br><br><a href="<?cs var:html_escape(Archive) ?>/">ߋOq</a>ɂ܂ł<br>₢킹Ă\͂قƂǂ܂<br>
 <?cs /if ?>
 
-<!--G[\I-->
-<?cs /if ?> <!-- IsPooled -->
-<?cs /if ?> <!-- IsError -->
+<?cs /if ?>
+<?cs /if ?>
 </body>
 </html>
 
