@@ -1,22 +1,21 @@
 <html>
 <head>
-<!--nobanner-->
 <title>img0ch - GAvbg̃LoX</title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="Robot" content="NOINDEX,NOFOLLOW">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<script src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script src="<?cs var:StaticURI ?>/js/jquery/fastserialize.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/fastserialize.js"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
 var app = Img0ch.App;
-app.setBBSURI("<?cs var:BBSURI ?>");
-app.setCGIURI("<?cs var:CGIURI ?>");
-app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
+app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
+app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
+app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
 
 /*
  * pallet from sugadokoro
@@ -80,7 +79,7 @@ function confirmSubmit() {
 
 function paintBBSCallback(callbackValue) {
     if (callbackValue == "header") {
-        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
+        var option = { "expires": 30, "path": "<?cs var:html_escape(BBS_COOKIE_PATH) ?>" };
         jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
         jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
         return jQuery.param(jQuery("form#notePostForm").fastSerialize());
@@ -89,41 +88,40 @@ function paintBBSCallback(callbackValue) {
 
 //-->
 </script>
-<!--meta.txto͕-->
 <?cs var:META ?>
 </head>
 
-<body bgcolor="<?cs var:BBS_BG_COLOR ?>" text="<?cs var:BBS_TEXT_COLOR ?>" link="<?cs var:BBS_LINK_COLOR ?>" alink="<?cs var:BBS_ALINK_COLOR ?>" vlink="<?cs var:BBS_VLINK_COLOR ?>" background="<?cs var:BBS_BG_PICTURE ?>">
+<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">
 
-<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:BBS_MENU_COLOR ?>">
+<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 
 <tr><td>
 <?cs if:UsePaintBBS ?><applet code="pbbs.PaintBBS.class"
-  archive="<?cs var:StaticURI ?>/applet/PaintBBS.jar"
-  name="paintbbs" width="<?cs var:CanvasWidth ?>" height="<?cs var:CanvasHeight ?>"
+  archive="<?cs var:html_escape(StaticURI) ?>/applet/PaintBBS.jar"
+  name="paintbbs" width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>"
   align="center" mayscript="mayscript"><?cs /if ?>
 <?cs if:UseShiiPainter ?><applet code="c.ShiPainter.class" name="paintbbs"
-  archive="<?cs var:StaticURI ?>/applet/spainter_all.jar"
-  width="<?cs var:CanvasWidth ?>" height="<?cs var:CanvasHeight ?>" mayscript="mayscript">
+  archive="<?cs var:html_escape(StaticURI) ?>/applet/spainter_all.jar"
+  width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>" mayscript="mayscript">
   <param name="tt.zip" value="tt.zip">
   <param name="res.zip" value="res_normal.zip">
   <param name="tools" value="normal"><?cs /if ?>
 <?cs if:UseShiiPainterPro ?><applet code="c.ShiPainter.class" name="paintbbs"
-  archive="<?cs var:StaticURI ?>/applet/spainter_all.jar"
-  width="<?cs var:CanvasWidth ?>" height="<?cs var:CanvasHeight ?>" mayscript="mayscript">
+  archive="<?cs var:html_escape(StaticURI) ?>/applet/spainter_all.jar"
+  width="<?cs var:html_escape(CanvasWidth) ?>" height="<?cs var:html_escape(CanvasHeight) ?>" mayscript="mayscript">
   <param name="tt.zip" value="tt.zip">
   <param name="res.zip" value="res_pro.zip">
   <param name="tools" value="pro"><?cs /if ?>
-  <param name="image_width" value="<?cs var:ImageWidth ?>">
-  <param name="image_height" value="<?cs var:ImageHeight ?>">
+  <param name="image_width" value="<?cs var:html_escape(ImageWidth) ?>">
+  <param name="image_height" value="<?cs var:html_escape(ImageHeight) ?>">
   <param name="image_bkcolor" value="#ffffff">
   <param name="compress_level" value="15">
   <param name="undo" value="90">
   <param name="undo_in_mg" value="15">
-  <param name="url_save" value="<?cs var:CGIURI ?>/img0ch-note.cgi">
-  <param name="url_exit" value="<?cs var:BBSURI ?>/">
+  <param name="url_save" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi">
+  <param name="url_exit" value="<?cs var:html_escape(BBSURI) ?>/">
   <param name="send_advance" value="true">
-  <param name="send_header" value="<?cs if:KEY ?>bbs=<?cs var:BBS ?>&key=<?cs var:KEY ?>&resno=<?cs var:ResNumber ?>&editpass=<?cs var:html_escape(EditPass) ?>&action=update<?cs else ?>bbs=<?cs var:BBS ?>&post=0&action=save<?cs /if ?>">
+  <param name="send_header" value="<?cs if:KEY ?>bbs=<?cs var:html_escape(BBS) ?>&key=<?cs var:html_escape(KEY) ?>&resno=<?cs var:html_escape(ResNumber) ?>&editpass=<?cs var:html_escape(EditPass) ?>&action=update<?cs else ?>bbs=<?cs var:html_escape(BBS) ?>&post=0&action=save<?cs /if ?>">
   <param name="send_header_count" value="true">
   <param name="send_header_image_type" value="true">
   <param name="send_header_timer" value="true">
@@ -136,11 +134,11 @@ function paintBBSCallback(callbackValue) {
   <param name="scriptable" value="true">
   <param name="MAYSCRIPT" value="true">
 <?cs if:ResNumber ?>
-  <param name="image_canvas" value="<?cs var:BBSURI ?>/img/<?cs var:KEY ?>/<?cs var:ResNumber ?>.<?cs var:Extension ?>">
-  <param name="pch_file" value="<?cs var:CGIURI ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:BBS ?>&key=<?cs var:KEY ?>&resno=<?cs var:ResNumber ?>"><?cs /if ?>
+  <param name="image_canvas" value="<?cs var:html_escape(BBSURI) ?>/img/<?cs var:html_escape(KEY) ?>/<?cs var:html_escape(ResNumber) ?>.<?cs var:html_escape(Extension) ?>">
+  <param name="pch_file" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:html_escape(BBS) ?>&key=<?cs var:html_escape(KEY) ?>&resno=<?cs var:html_escape(ResNumber) ?>"><?cs /if ?>
 <?cs if:DraftId ?>
-  <param name="image_canvas" value="<?cs var:CGIURI ?>/img0ch-note.cgi?action=load&bbs=<?cs var:BBS ?>&draft=<?cs var:DraftId ?>">
-  <param name="pch_file" value="<?cs var:CGIURI ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:BBS ?>&draft=<?cs var:DraftId ?>"><?cs /if ?>
+  <param name="image_canvas" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=load&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(DraftId) ?>">
+  <param name="pch_file" value="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi?action=pch&bbs=<?cs var:html_escape(BBS) ?>&draft=<?cs var:html_escape(DraftId) ?>"><?cs /if ?>
 <?cs if:EnableJPEG ?>
   <param name="image_jpeg" value="true">
   <param name="image_size" value="1"><?cs else ?>
@@ -224,18 +222,18 @@ esɂJavaScriptLɂKv܂B
 </strong></span>
 </noscript>
 <form class="comment" id="notePostForm" method="POST"
-  action="<?cs var:CGIURI ?>/img0ch-note.cgi"
+  action="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi"
   onsubmit="confirmSubmit(); return false">
 <input type="submit" value="e" name="submit">
-<input type="hidden" name="bbs" value="<?cs var:BBS ?>">
-<input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
+<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
+<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
 <input type="hidden" name="post" value="0">
 <input type="hidden" name="action" value="save">
 <input type="checkbox" name="temporary" value="1" id="temporarySave">
 <label for="temporarySave">ړe摜̈ꎞۑs</label><br>
 eXbhF<select name="key">
 <?cs each:item = Threads ?>
-<option value="<?cs var:item.key ?>"><?cs var:item.subject ?>(<?cs var:item.res ?>)</option>
+<option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?>(<?cs var:html_escape(item.res) ?>)</option>
 <?cs /each ?>
 </select><br>
 OF<input type="text" name="FROM" size="19">
