@@ -1,13 +1,11 @@
 <html>
 <head>
-<!--nobanner-->
 <title>img0ch - GAvbg̕`r̉摜ꗗ</title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="Robot" content="NOINDEX,NOFOLLOW">
 <meta name="VERSION" content="<TMPL_VAR NAME=VERSION ESCAPE=HTML>">
-<!--meta.txto͕-->
 <?cs var:META ?>
 </head>
 
