@@ -1,13 +1,13 @@
 <html>
 <head>
-<!--nobanner-->
 <title><?cs var:html_escape(BBS_TITLE) ?>̃Xbh쐬tH[</title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script><script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
 var app = Img0ch.App;
@@ -25,7 +25,6 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
 .image { border: none; float: left; }
 -->
 </style>
-<!--meta.txto͕-->
 <?cs var:META ?>
 </head>
 
@@ -37,15 +36,12 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
 <?cs /if ?>
 
 <a name="info" />
-
-<!--[J[̘ggݕ\-->
 <table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
  <tr>
   <td>
    <table border="0" width="100%">
     <tr>
      <td>
-      <!--f̃Tu^Cg\-->
       <b><big><?cs var:html_escape(BBS_SUBTITLE) ?></big></b>
      </td>
      <td align=right>
@@ -54,7 +50,6 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
     </tr>
     <tr>
      <td colspan="2">
-      <!--[J[\-->
       <?cs var:HEAD ?>
      </td>
     </tr>
@@ -63,18 +58,15 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
  </tr>
  <tr>
   <td align="center">
-   <!--contents.html̃t[(index.html)ɖ߂郊N̕\-->
    <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
   </td>
  </tr>
 </table>
 <br>
 
-<!--L\-->
-<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>
+<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><br><?cs /if ?>
 
 <a name="thread" />
-<!--XbhVK쐬e[u\-->
 <table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
  <tr>
   <td>
@@ -85,11 +77,13 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
     <table border=0>
      <tr>
       <td>
-       <!--tH[\-->
         ^CgF<input type="text" name="subject" size="25">@<input type="submit" value="VKXbh쐬"><br>
         O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
        E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
        <?cs if:UploadableFromThread ?>摜F<input type="file" name="file" size="80"><br><?cs /if ?>
+       <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
+       <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
+       <?cs /each ?></select><br><?cs /if ?>
        <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
        <?cs if:UploadableFromThread ?><br>폜pXF<input type="password" name="pass"><?cs /if ?>
       </td>
