@@ -9,11 +9,11 @@
 <meta http-equiv="Content-Script-Type" content="text/javascript" />
 <meta http-equiv="Content-Style-Type" content="text/css" />
 <meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
@@ -25,24 +25,19 @@ app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
 //]]>
 </script>
 <style type="text/css">
-/*
-<![CDATA[
-*/
-a { color: <?cs var:html_escape(BBS_LINK_COLOR) ?>; }
-a:active { color: <?cs var:html_escape(BBS_ALINK_COLOR) ?>; }
-a:visited { color: <?cs var:html_escape(BBS_VLINK_COLOR) ?>; }
-body { font-family: "Mona","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS PSVbN","MS PSVbN",sans-serif; }
+@charset "shift_jis";
 fieldset { border: 0px; }
 img { border: 0px; }
 .center { text-align:center !important;  }
 .clear { clear: both !important; }
 .icon-align { vertical-align: top; }
 .image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-.nomail { color: <?cs var:html_escape(BBS_NAME_COLOR) ?> }
 .right { text-align: right !important; }
-.thread_info {}
-.res_body { line-height: 110% !important; }
-/* ]]> */
+.res_body {
+  font-size: 12pt;
+  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
+  line-height: 115% !important;
+}
 </style>
 <?cs var:META ?>
 </head>
@@ -75,7 +70,7 @@ img { border: 0px; }
    <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
    <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
    <?cs each:item = LinkStack ?>
-    <a href="<?cs var:html_escape(iReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>">
+    <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>">
      <?cs var:html_escape(item.start) ?>-
     </a>
    <?cs /each ?>
@@ -103,13 +98,13 @@ img { border: 0px; }
      <?cs var:html_escape(res.resno) ?>
      OF<span class="commentator">
      <?cs if:res.mail ?>
-      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:html_escape(res.name) ?></b></a>
+      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
      <?cs else ?>
-      <span class="nomail"><b><?cs var:html_escape(res.name) ?></b></span>
+      <span class="nomail"><b><?cs var:res.name ?></b></span>
      <?cs /if ?>
      </span>:<span class="commenttime"><?cs var:html_escape(res.date) ?></span>
     </div>
-    <p class="res_body"><?cs var:html_escape(res.text) ?></p>
+    <p class="res_body"><?cs var:res.text ?></p>
    </div>
   <?cs /each ?>
  </div>
@@ -121,21 +116,30 @@ img { border: 0px; }
     <input type="hidden" name="key" value="<?cs var:html_escape(key) ?>" />
     <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
    </div>
-   <div class="field name">
-    OF<input type="text" name="FROM" value="" size="19" />
-   </div>
-   <div class="field mail">
-    [F<input type="text" name="mail" value="" size="19" />
+   <div>
+    <div class="field name">
+     OF<input type="text" name="FROM" value="" size="19" />
+    </div>
+    <div class="field mail">
+     [F<input type="text" name="mail" value="" size="19" />
+    </div>
    </div>
    <?cs if:UploadableFromRes ?>
-   <div class="field name">
-    <br />摜F<input type="file" name="file" />
-   </div>
-   <?cs if:UploadableFromRes ?>
-   <div class="field mail">
-    폜pXF<input type="password" name="pass" />
+   <div>
+    <div class="field name">
+     摜F<input type="file" name="file" />
+    </div>
+    <div class="field mail">
+     폜pXF<input type="password" name="pass" />
+    </div>
    </div>
    <?cs /if ?>
+   <?cs if:Icon ?>
+   <div class="textarea">
+    ACRF<select name="icon"><option value="" selected="selected">Ȃ</option>
+    <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
+    <?cs /each ?></select>
+   </div>
    <?cs /if ?>
    <div class="textarea">
     RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
@@ -158,7 +162,7 @@ img { border: 0px; }
 </div>
 
 <div class="footer">
- <?cs var:html_escape(VERSION) ?>
+ <a href="http://img0ch.sourceforge.jp"><?cs var:html_escape(VERSION) ?></a>
 </div>
 
 </body>
