@@ -9,10 +9,10 @@
 <meta http-equiv="Content-Script-Type" content="text/javascript" />
 <meta http-equiv="Content-Style-Type" content="text/css" />
 <meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
@@ -73,17 +73,19 @@ div#searchForm {
    <p>
     <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
     <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
+    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">Ytt@C</a>
    </p>
   </div>
   <div id="searchForm" class="section">
    <div class="field">
     <input type="text" name="query" value="<?cs var:Query ?>" size="50" />
     <select name="type">
-     <option value="FROM">O</option>
-     <option value="mail">[</option>
-     <option value="date"></option>
-     <option value="id">ID</option>
-     <option value="MESSAGE" selected="selected">{</option>
+     <option value="subject"<?cs if:SelectedSubject ?> selected="selected"<?cs /if ?>>Xbh̑薼</option>
+     <option value="FROM"<?cs if:SelectedFrom ?> selected="selected"<?cs /if ?>>O</option>
+     <option value="mail"<?cs if:SelectedMail ?> selected="selected"<?cs /if ?>>[</option>
+     <option value="date"<?cs if:SelectedDate ?> selected="selected"<?cs /if ?>></option>
+     <option value="id"<?cs if:SelectedId ?> selected="selected"<?cs /if ?>>ID</option>
+     <option value="MESSAGE"<?cs if:SelectedMessage ?> selected="selected"<?cs /if ?>>{</option>
     </select>
    </div>
    <div><input type="submit" value="Jn" <?cs if:Disabled ?>disabled="disabled" <?cs /if ?>/></div>
@@ -122,7 +124,7 @@ div#searchForm {
     </span>:<span class="commenttime"><?cs var:html_escape(item.date) ?></span>
    </div>
    <p class="res_body"><?cs var:item.text ?></p>
-   <div class="from"><hr /><a href="<?cs var:CGIURI ?>/read.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.subject ?></a>&nbsp;(<?cs var:item.count ?>X̂<?cs var:item.found ?>Y)</div>
+   <div class="from"><hr /><a href="<?cs var:CGIURI ?>/read.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.subject ?></a><?cs if:item.found ?>&nbsp;(<?cs var:item.count ?>X̂<?cs var:item.found ?>Y)<?cs /if ?></div>
    </div>
   <?cs /each ?>
  </div>
