@@ -8,12 +8,12 @@
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />
 <meta http-equiv="Content-Script-Type" content="text/javascript" />
 <meta http-equiv="Content-Style-Type" content="text/css" />
-<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
+<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
