@@ -30,9 +30,9 @@
 <?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象の過去ログスレッドが選択されていません</p></div><?cs /if ?>
 <?cs /if ?>
 
-<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
 <script type="text/javascript" charset="UTF-8">
 //<![CDATA[
 jQuery(function(){
@@ -51,7 +51,7 @@ function lookup( ip, element, event ) {
 <p>
 <ul>
 <li>IPアドレス欄はIPアドレスをクリックし、赤くなったらもう一度クリックすることで詳細が表示されます。</li>
-<li><code style="font-weight:bold">[!]</code>をクリックすることで投稿者の投稿記録が全て表示されます。</li>
+<li><code style="font-weight:bold">[HL]</code>をクリックすることで投稿者の投稿記録が全て表示されます。</li>
 </ul>
 </p>
 
@@ -83,7 +83,7 @@ function lookup( ip, element, event ) {
   </thead>
   <tbody>
   <?cs each:item = Entries ?>
-    <tr><td><input type="checkbox" name="thread" value="<?cs var:html_escape(item.key) ?>" /></td><td><?cs var:item.subject ?></td><td><?cs var:html_escape(item.count) ?></td><td title="<?cs var:html_escape(item.key) ?>"><code><?cs var:html_escape(item.date) ?></code></td><td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(item.ip) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">[!]</a></td></tr>
+    <tr><td><input type="checkbox" name="thread" value="<?cs var:html_escape(item.key) ?>" /></td><td><?cs var:item.subject ?></td><td><?cs var:html_escape(item.count) ?></td><td title="<?cs var:html_escape(item.key) ?>"><code><?cs var:html_escape(item.date) ?></code></td><td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(item.ip) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">[HL]</a></td></tr>
   <?cs /each ?>
   </tbody>
 </table>
