@@ -14,12 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 955 2007-08-05 15:15:13Z hikarin $
+# $Id: BBS.pm 1483 2007-10-25 12:59:40Z hikarin $
 #
 
 package Img0ch::App::BBS;
 
 use strict;
+use Img0ch::BBS qw();
+use Img0ch::Template qw();
+use Img0ch::Thread qw();
 
 BEGIN {
     my $pkg = __PACKAGE__;
@@ -73,6 +76,7 @@ sub new {
         __template_tag_redirect     => [],
         __template_tag_subback      => [],
         __thread                    => undef,
+        __thread_posision           => 'age',
     }, $iClass;
 }
 
@@ -90,6 +94,7 @@ sub run {
         or return $iApp->redirect_error('error');
     $iApp->update_index( undef, 1, 0 );
     $iApp->redirect_success();
+
     return 1;
 }
 
@@ -102,44 +107,50 @@ sub init {
         and die 'img0ch MAINTENANCE: Please try again later.', "\n";
     $iRequest->init($iConfig);
 
-    require Img0ch::BBS;
     my $iBBS
         = Img0ch::BBS->new( $iApp->{__kernel}, { bbs => $iRequest->bbs(), } );
     if ( !$iBBS->get_id() ) {
         $iApp->{__error} = 'INVALID_POST';
         return 0;
     }
-    $iApp->{__bbs} = $iBBS;
-
-    require Img0ch::Setting;
-    my $iSetting = Img0ch::Setting->new($iBBS);
-    $iSetting->load();
-    $iApp->{__setting} = $iSetting;
+    $iApp->{__bbs}     = $iBBS;
+    $iApp->{__setting} = $iBBS->get_setting_instance();
 
     my $now = $iRequest->now();
     $iApp->{__agent} = $iRequest->agent();
     $iApp->{__now}   = $now;
 
-    my $key = $iRequest->key();
+    my $key = $iRequest->param('key');
     if ( !$iConfig->get('DisableThread924') and $key =~ /\A924\d+\z/xms ) {
         $iApp->{__error} = 'POST_SPECIAL_THREAD';
         return 0;
     }
 
-    require Img0ch::Thread;
-    my $iThread = Img0ch::Thread->new( $iBBS, $key );
-    if ( $iThread->load() ) {
-        $iApp->{__mkthread} = 0;
-        $iApp->{__key}      = $key;
+    my $iThread;
+    if ( !$key ) {
+        $key     = $now;
+        $iThread = $iBBS->get_thread_instance($key);
+        if ( $iThread->count() ) {
+            $iApp->{__error} = 'THREAD_HAS_BEEN_CREATED';
+            return 0;
+        }
+        $iApp->{__mkthread} = 1;
     }
     else {
-        $iApp->{__mkthread} = 1;
-        $iApp->{__key}      = $now;
+        $iThread = $iBBS->get_thread_instance($key);
+        if ( !$iThread->count() ) {
+            $iApp->{__error} = 'THREAD_NOT_FOUND';
+            return 0;
+        }
+        $iApp->{__mkthread} = 0;
     }
+
+    $iApp->{__key}    = $key;
     $iApp->{__thread} = $iThread;
     $iApp->_plugin( $iBBS, $iConfig, 'bbs.init', 'DisableBBSInitPlugin' )
         or return 0;
-    1;
+
+    return 1;
 }
 
 sub get_host {
@@ -178,59 +189,67 @@ sub get_host {
             return 0;
         }
     }
-    1;
+
+    return 1;
 }
 
 sub validate {
     my ($iApp)   = @_;
     my $iBBS     = $iApp->{__bbs};
     my $iConfig  = $iApp->{_config};
+    my $iKernel  = $iApp->{__kernel};
     my $iSetting = $iApp->{__setting};
     my $iRequest = $iApp->{_request};
-    my $charset  = $iApp->{__kernel}->get_encoding(1);
+    my $charset  = $iKernel->get_encoding(1);
+    my $utf8 = $iRequest->param('utf8') ? 'utf8' : undef;
     my ( $name, $mail, $comment, $subject );
 
     if ( $charset eq 'sjis' ) {
 
         # code from ShiftJIS::String by SADAHIRO tomoyuki
-        my $is_sjis = sub {
-            my $str = shift || '';
+        my $is_sjis_function = sub {
+            my $str = shift || return 1;
             $str =~ s/[\x00-\x7F\xA1-\xDF]|
                 [\x81-\x9F\xE0-\xFC][\x40-\x7E\x80-\xFC]//gxms;
             return length $str ? 0 : 1;
         };
         $name = $iRequest->param('FROM');
-        if ( !$is_sjis->($name) ) {
-            $name = $iRequest->param_multibyte( 'FROM', $charset );
-        }
+        ( $utf8 or !$is_sjis_function->($name) )
+            and $name = $iKernel->get_encoded_str( $name, $charset, $utf8 );
         $mail = $iRequest->param('mail');
-        if ( !$is_sjis->($mail) ) {
-            $mail = $iRequest->param_multibyte( 'mail', $charset );
-        }
+        ( $utf8 or !$is_sjis_function->($mail) )
+            and $mail = $iKernel->get_encoded_str( $mail, $charset, $utf8 );
         $comment = $iRequest->param('MESSAGE');
-        if ( !$is_sjis->($comment) ) {
-            $comment = $iRequest->param_multibyte( 'MESSAGE', $charset );
-        }
+        ( $utf8 or !$is_sjis_function->($comment) )
+            and $comment
+            = $iKernel->get_encoded_str( $comment, $charset, $utf8 );
         $subject = $iRequest->param('subject');
-        if ( !$is_sjis->($subject) ) {
-            $subject = $iRequest->param_multibyte( 'subject', $charset );
-        }
+        ( $utf8 or !$is_sjis_function->($subject) )
+            and $subject
+            = $iKernel->get_encoded_str( $subject, $charset, $utf8 );
     }
     else {
-        $name    = $iRequest->param_multibyte( 'FROM',    $charset );
-        $mail    = $iRequest->param_multibyte( 'mail',    $charset );
-        $comment = $iRequest->param_multibyte( 'MESSAGE', $charset );
-        $subject = $iRequest->param_multibyte( 'subject', $charset );
+        $name = $iKernel->get_encoded_str( $iRequest->param('FROM'),
+            $charset, $utf8 );
+        $mail = $iKernel->get_encoded_str( $iRequest->param('mail'),
+            $charset, $utf8 );
+        $comment = $iKernel->get_encoded_str( $iRequest->param('MESSAGE'),
+            $charset, $utf8 );
+        $subject = $iKernel->get_encoded_str( $iRequest->param('subject'),
+            $charset, $utf8 );
     }
 
-    require Img0ch::Cap;
     $mail =~ s/&(?:amp;)?\#(\d+;)/&&$1/gxms;
     $mail =~ s/\#(.+)\z//xms;
     my $pass = $1 || '';
-    my $iCap = Img0ch::Cap->new( $iBBS, $pass );
+    my $iCap = $iBBS->get_cap_instance($pass);
     $iCap->load();
     $iCap->is_valid();
-    $mail =~ s/&&(\d+;)/&#$1/gxms;
+
+    my $enable_unicode = $iSetting->get('BBS_UNICODE') eq 'change' ? 0 : 1;
+    $enable_unicode
+        ? $mail =~ s/&&(\d+;)/&#$1/gxms
+        : $mail =~ s/&&(\d+;)/&amp;#$1/gxms;
 
     my $limitless = $iCap->can_post_without_limit();
     if ( !$limitless ) {
@@ -242,7 +261,11 @@ sub validate {
 
     $name =~ tr/\r\n\t//d;
     $mail =~ tr/\r\n\t//d;
-    ( index( $mail, 'sage' ) >= 0 ) and $iApp->{__sage} = 1;
+    my $mkthread = $iApp->{__mkthread};
+    if ( !$mkthread and index( $mail, 'sage' ) >= 0 ) {
+        $iApp->{__sage}            = 1;
+        $iApp->{__thread_posision} = 'sage';
+    }
 
     if ( !$limitless ) {
         if ( $iSetting->get_int('BBS_NAME_COUNT') < length $name ) {
@@ -275,6 +298,7 @@ sub validate {
     my $host = $iApp->{_host};
     $name =~ s|\Afusianasan|</b>$host<b>|xms;
     $name =~ s|fusianasan| </b>$host<b>|gxms;
+
     if ($capn) {
         my $atmark = $iConfig->get('multibyte.ATMARK')
             || pack( 'C*', ( 0x81, 0x97 ) );
@@ -339,13 +363,15 @@ sub validate {
         %{ $iApp->{__annotation} } = %$hash;
         $comment = join "\n", @new_comment;
     }
+
     $comment =~ s/\A\s+//xms;
     $comment =~ s/\s+\z//xms;
     $comment =~ s/\r\n/\n/gxms;
     $comment =~ s/\n/<br>/gxms;
     $comment =~ tr/\r\t//d;
+    $enable_unicode and $comment =~ s/&amp;(\#?\w+;)/&$1/gxms;
 
-    if ( $iApp->{__mkthread} ) {
+    if ($mkthread) {
         if ( $subject eq '' ) {
             $iApp->{__error} = 'NO_SUBJECT';
             return 0;
@@ -356,15 +382,16 @@ sub validate {
                 return 0;
             }
         }
+        $subject =~ tr/\r\n\t//d;
+        $iApp->{__param_subject} = $subject;
     }
-    $subject =~ tr/\r\n\t//d;
 
     $iApp->{__cap}           = $iCap;
     $iApp->{__param_FROM}    = $name;
     $iApp->{__param_mail}    = $mail;
     $iApp->{__param_MESSAGE} = $comment;
-    $iApp->{__param_subject} = $subject;
-    1;
+
+    return 1;
 }
 
 sub is_writeable {
@@ -399,7 +426,6 @@ sub is_writeable {
             $iApp->{__error} = 'POST_CAPONLY_BBS';
             return 0;
         }
-        require Img0ch::Filter::Thread;
         if ( !$iCap->can_create_thread_limitless() ) {
             my $args = {
                 ip    => $iApp->{_ip_int},
@@ -407,6 +433,8 @@ sub is_writeable {
                 pass  => $iCap->can_create_thread_limitless(),
                 stamp => $iApp->{__now},
             };
+            defined &{'Img0ch::Filter::Thread::write_ok'}
+                or require Img0ch::Filter::Thread;
             if ( !Img0ch::Filter::Thread->write_ok( $args, $iBBS ) ) {
                 $iApp->{__error} = $args->{error};
                 return 0;
@@ -414,7 +442,6 @@ sub is_writeable {
         }
     }
     else {
-        require Img0ch::Filter::Res;
         my $iThread  = $iApp->{__thread};
         my $mkthread = $iApp->{__mkthread};
         my $error    = 0;
@@ -445,7 +472,9 @@ sub is_writeable {
             timecount    => $iSetting->get_int('timecount'),
             throttle_ok  => $iCap->can_throttled_post(),
         };
-        if ( !Img0ch::Filter::Res->write_ok( $args, $iApp->{__kernel} ) ) {
+        defined &{'Img0ch::Filter::Res::write_ok'}
+            or require Img0ch::Filter::Res;
+        if ( !Img0ch::Filter::Res->write_ok( $args, $iBBS ) ) {
             $iApp->{__error} = $args->{error};
             %{ $iApp->{__error_args} } = (
                 WAIT    => $args->{samba_rest},
@@ -455,7 +484,8 @@ sub is_writeable {
             return 0;
         }
     }
-    1;
+
+    return 1;
 }
 
 sub get_date {
@@ -508,7 +538,8 @@ sub get_date {
             )
         ),
     );
-    1;
+
+    return 1;
 }
 
 sub post {
@@ -540,8 +571,7 @@ sub post {
             or return 0;
     }
 
-    require Img0ch::Log;
-    my $iLog = Img0ch::Log->new( $iBBS, $key );
+    my $iLog = $iBBS->get_log_instance($key);
     $iLog->add(
         $count,
         [   $iApp->{__now},   $iApp->{_ip_int},
@@ -559,17 +589,14 @@ sub post {
     $iThread->save() or return 0;
 
     if ( $iApp->{__resmax} <= $count ) {
-        require Img0ch::Metadata;
-        my $iMeta   = Img0ch::Metadata->new($iBBS);
+        my $iMeta   = $iBBS->get_metadata_instance();
         my $content = $iMeta->thread_end();
         if ( !$content ) {
             my $iKernel = $iApp->{__kernel};
-            my $path = join '/', $iConfig->get('SystemPath'), '1000.txt';
-            local ( *FH, $! );
-            open *FH, "<${path}"    ## no critic
-                or $iKernel->throw_io_exception($path);
-            $content = do { local $/ = undef; <FH> };
-            close *FH or $iKernel->throw_io_exception($path);
+            my $path    = join '/', $iConfig->get('SystemPath'), '1000.txt';
+            my $fh      = $iKernel->get_read_file_handle($path);
+            $content = do { local $/ = undef; <$fh> };
+            close $fh or $iKernel->throw_io_exception($path);
         }
         my $end = [ split '<>', $content ];
         $end->[4] = $end->[3];
@@ -579,19 +606,13 @@ sub post {
         $count++;
     }
 
-    require Img0ch::Subject;
-    my $iSubject = Img0ch::Subject->new($iBBS);
-    $iSubject->load();
-    if ( !$mkthread and $iApp->{__sage} ) {
-        $iSubject->sage( $key, $count );
-    }
-    else {
-        $iSubject->age( $key, $count, $iApp->{__param_subject} );
-    }
+    my $iSubject = $iBBS->get_subject_instance();
+    my $operate  = $iApp->{__thread_posision};
+    $iSubject->$operate( $key, $count, $iApp->{__param_subject} );
     $iSubject->save() or return 0;
     $iApp->{__subject} = $iSubject;
 
-    1;
+    return 1;
 }
 
 sub update_subback {
@@ -609,45 +630,38 @@ sub update_subback {
     my $stack    = [];
     my $i        = 1;
     my $iSetting = $iApp->{__setting};
-    if ( !$iSetting ) {
-        require Img0ch::Setting;
-        $iSetting = Img0ch::Setting->new($iBBS);
-        $iSetting->load();
-    }
+    $iSetting
+        or $iSetting = $iApp->{__setting} = $iBBS->get_setting_instance();
     my $iSubject = $iApp->{__subject};
-    if ( !$iSubject ) {
-        require Img0ch::Subject;
-        $iSubject = Img0ch::Subject->new($iBBS);
-        $iSubject->load();
-    }
+    $iSubject
+        or $iSubject = $iApp->{__subject} = $iBBS->get_subject_instance();
 
     for my $key ( @{ $iSubject->to_array() } ) {
         my $subj = $iSubject->get($key);
         push @{$stack},
             {
-            'res'     => $subj->[1],
-            'key'     => $key,
-            'subject' => $subj->[0],
-            'count'   => $i,
-            'index'   => $i,
+            'res' => $subj->[1],
+            'key' => $key,
+            'subject' =>
+                ( $subj->[0] || $iApp->recover_thread_subject($key) ),
+            'count' => $i,
+            'index' => $i,
             };
         $i++;
     }
 
-    require Img0ch::Metadata;
-    require Img0ch::Template;
-    my $iMeta = Img0ch::Metadata->new($iBBS);
+    my $iMeta = $iBBS->get_metadata_instance();
     my $param = {
         ( map { %{$_} } @{ $iApp->{__template_tag_subback} } ),
         'Banner'            => $iMeta->main_banner(),
+        'META'              => $iMeta->meta(),
         'Renderer'          => ( $iConfig->get('Renderer') || 'read.cgi' ),
         'RendererSeparator' => ( $iConfig->get('RendererSeparator') || '/' ),
         'Threads'           => $stack,
     };
     $nodisk and return $param;
 
-    my $iTemplate = Img0ch::Template->new(
-        $iBBS,
+    my $iTemplate = $iBBS->get_template_instance(
         {   file    => 'subback',
             request => $iApp->{_request},
             setting => $iSetting,
@@ -667,30 +681,17 @@ sub update_index {
     $iConfig->get('FastWriteMode') and return 1;
     $iBBS ||= $iApp->{__bbs};
 
-    require Img0ch::Plugin;
-    my $iPlugin = $iApp->{__plugin} || Img0ch::Plugin->new($iBBS);
+    my $iPlugin = $iApp->{__plugin} || $iBBS->get_plugin_instance();
     my $plugin = $iPlugin->iterator( 'bbs.rewrite', sub { ${ $_[3] } } );
 
     my $iSetting = $iApp->{__setting};
-    if ( !$iSetting ) {
-        require Img0ch::Setting;
-        $iSetting = Img0ch::Setting->new($iBBS);
-        $iSetting->load();
-        $iApp->{__setting} = $iSetting;
-    }
+    $iSetting
+        or $iSetting = $iApp->{__setting} = $iBBS->get_setting_instance();
     my $iSubject = $iApp->{__subject};
-    if ( !$iSubject ) {
-        require Img0ch::Subject;
-        $iSubject = Img0ch::Subject->new($iBBS);
-        $iSubject->load();
-        $iApp->{__subject} = $iSubject;
-    }
+    $iSubject
+        or $iSubject = $iApp->{__subject} = $iBBS->get_subject_instance();
     my $iThread = $iApp->{__thread};
-    if ( !$iThread ) {
-        require Img0ch::Thread;
-        $iThread = Img0ch::Thread->new( $iBBS, 0 );
-        $iApp->{__thread} = $iThread;
-    }
+    $iThread or $iThread = $iApp->{__thread} = $iBBS->get_thread_instance(0);
     $iConfig->get('EnableXHTMLBreak') and $iThread->enable_xhtml_break();
 
     my $all_threads         = $iSubject->to_array();
@@ -722,7 +723,7 @@ sub update_index {
                 {
                 'res'     => $count,
                 'key'     => $key,
-                'subject' => $subj->[0],
+                'subject' => $iThread->get_subject(),
                 'index'   => $i,
                 'reses'   => $reses,
                 'Thread'  => $reses,
@@ -733,17 +734,17 @@ sub update_index {
         else {
             push @{$stored_thread_stack},
                 {
-                'res'     => $count,
-                'key'     => $key,
-                'subject' => $subj->[0],
-                'index'   => $i,
+                'res' => $count,
+                'key' => $key,
+                'subject' =>
+                    ( $subj->[0] || $iApp->recover_thread_subject($key) ),
+                'index' => $i,
                 };
         }
         $i++;
     }
 
-    require Img0ch::Metadata;
-    my $iMeta       = $iApp->{__meta} || Img0ch::Metadata->new($iBBS);
+    my $iMeta       = $iApp->{__meta} || $iBBS->get_metadata_instance();
     my $head        = $iMeta->head();
     my $meta        = $iMeta->meta();
     my $foot        = $iMeta->foot();
@@ -779,9 +780,7 @@ sub update_index {
     };
     $nodisk and return ( $index_param, $mi_param );
 
-    require Img0ch::Template;
-    my $iTemplateIndex = Img0ch::Template->new(
-        $iBBS,
+    my $iTemplateIndex = $iBBS->get_template_instance(
         {   file    => 'index',
             request => $iRequest,
             setting => $iSetting,
@@ -790,8 +789,7 @@ sub update_index {
     $iTemplateIndex->param($index_param);
     $iTemplateIndex->save( $iBBS->path('index.html') );
 
-    my $iTemplateMobile = Img0ch::Template->new(
-        $iBBS,
+    my $iTemplateMobile = $iBBS->get_template_instance(
         {   file    => 'i_index',
             request => $iRequest,
             setting => $iSetting,
@@ -806,7 +804,6 @@ sub update_index {
 sub get_poster_id {
     my ( $iClass, $now, @argument ) = @_;
     my @time = localtime($now);
-    require Digest::MD5;
     return substr Digest::MD5::md5_base64(
         @argument, $time[5], $time[4], $time[3] + 31
         ),
@@ -926,10 +923,10 @@ sub get_text_info {
     $$ptext =~ /\n/xms || return ( 1, length $$ptext );
     my $text = $$ptext;
 
-    require List::Util;
+    defined $List::Util::VERSION or require List::Util;
     my $max = List::Util::maxstr( split "\n", $$ptext ) || '';
 
-    ( $text =~ tr/\n//d, length $max );
+    return ( $text =~ tr/\n//d, length $max );
 }
 
 sub count_anchors {
@@ -943,7 +940,7 @@ sub is_bbm {
     my $addr = sprintf 'img0ch.%s.%s.%s.bbm.2ch.net', $$, ( $now || time ),
         $serial;
     $addr = gethostbyname($addr) || '';
-    join( '.', ( unpack( 'C*', $addr ) ) ) eq '127.0.0.2' ? 1 : 0;
+    return join( '.', ( unpack( 'C*', $addr ) ) ) eq '127.0.0.2' ? 1 : 0;
 }
 
 sub get_plugin_config {
@@ -954,16 +951,16 @@ sub get_plugin_config {
     my $ret     = [];
 
     if ( $merge_level & 2 ) {
-        my $config
+        my $config_thread
             = Img0ch::Plugin->retrive( $plugin_id, $bbs, $key, $iKernel );
-        ( ( ref $config || '' ) eq 'HASH' )
-            and push @$ret, $config->{$name};
+        ( ( ref $config_thread || '' ) eq 'HASH' )
+            and push @$ret, $config_thread->{$name};
     }
     if ( $merge_level & 1 ) {
-        my $config
+        my $config_bbs
             = Img0ch::Plugin->retrive( $plugin_id, $bbs, undef, $iKernel );
-        ( ( ref $config || '' ) eq 'HASH' )
-            and push @$ret, $config->{$name};
+        ( ( ref $config_bbs || '' ) eq 'HASH' )
+            and push @$ret, $config_bbs->{$name};
     }
     my $config
         = Img0ch::Plugin->retrive( $plugin_id, undef, undef, $iKernel );
@@ -1039,6 +1036,32 @@ sub stash {
     return $iApp->{__stash}->{$key};
 }
 
+sub get_thread_position { $_[0]->{__thread_posision} }
+
+sub set_thread_position {
+    my ( $iApp, $pos ) = @_;
+    $iApp->{__thread_posision} = {
+        'age'   => 'age',
+        'raise' => 'age',
+        'sage'  => 'sage',
+        'stay'  => 'sage',
+        'dame'  => 'dame',
+        'drop'  => 'dame',
+        }->{$pos}
+        || 'age';
+    return;
+}
+
+sub recover_thread_subject {
+    my ( $iApp, $key ) = @_;
+    my $iBBS     = $iApp->{__bbs}     || return;
+    my $iSubject = $iApp->{__subject} || $iBBS->get_subject_instance();
+    my $iThread  = $iApp->{__thread}  || $iBBS->get_thread_instance($key);
+    my $subject = $iThread->get_subject();
+    $iSubject->sage( $key, $iThread->count(), $subject );
+    return $subject;
+}
+
 sub _switch {
     my ($iApp) = @_;
     my $agent  = $iApp->{__agent};
@@ -1046,16 +1069,13 @@ sub _switch {
     my $key    = $iApp->{__key};
 
     if ( $iApp->{__mkthread} ) {
-        require Img0ch::Template;
         my $iRequest = $iApp->{_request};
         my $iSetting = $iApp->{__setting};
         my $comment  = $iRequest->param('MESSAGE');
         my $pwcheck  = $iSetting->is_checked('BBS_PASSWORD_CHECK');
         if ( !$agent and $pwcheck and !$comment ) {
-            require Img0ch::Metadata;
-            my $iMeta     = Img0ch::Metadata->new($iBBS);
-            my $iTemplate = Img0ch::Template->new(
-                $iBBS,
+            my $iMeta     = $iBBS->get_metadata_instance();
+            my $iTemplate = $iBBS->get_template_instance(
                 {   file    => 't_form',
                     request => $iRequest,
                     setting => $iSetting,
@@ -1074,7 +1094,8 @@ sub _switch {
             return 0;
         }
     }
-    1;
+
+    return 1;
 }
 
 sub trigger_plugin {
@@ -1091,12 +1112,12 @@ sub _plugin {
     my ( $iApp, $iBBS, $iConfig, $at, $disable ) = @_;
 
     if ( !$iConfig->get($disable) ) {
-        require Img0ch::Plugin;
-        my $iPlugin = $iApp->{__plugin} || Img0ch::Plugin->new($iBBS);
+        my $iPlugin = $iApp->{__plugin} || $iBBS->get_plugin_instance();
         $iPlugin->do( $at, $iApp ) or return 0;
         $iApp->{__plugin} ||= $iPlugin;
     }
-    1;
+
+    return 1;
 }
 
 sub _upload {
@@ -1110,8 +1131,7 @@ sub _upload {
         return 0;
     }
 
-    require Img0ch::Upload;
-    my $iUpload = Img0ch::Upload->new( $iBBS, $key );
+    my $iUpload = $iBBS->get_upload_instance($key);
     $iApp->{__upload} = $iUpload;
 
     if ( $iUpload->count() > $iSetting->get_int('BBS_IMG_FILEMAX') ) {
@@ -1146,6 +1166,11 @@ sub _upload {
         or return 0;
 
     $iUpload->set( $iRequest->tempfile(), $resno, $ext );
+    if ( $iUpload->is_removed() ) {
+        $iApp->{__error} = 'UPLOAD_REMOVED_FILE';
+        return 0;
+    }
+
     $iUpload->set_remove_password($remove_key);
     $iUpload->save();
 
@@ -1165,14 +1190,15 @@ sub _upload {
     $iApp->_plugin( $iBBS, $iConfig, 'bbs.upload.post',
         'DisableBBSPostUploadPlugin' )
         or return 0;
-    1;
+
+    return 1;
 }
 
 sub _acceptable {
     my ( $iApp, $iSetting, $file, $ext ) = @_;
-    my $allow = $iSetting->get('BBS_IMG_ALLOWED_EXT');
-    my @ext = $allow =~ /,/xms ? split ',', $allow : ($allow);
-    if ( $ext[0] eq '' or @ext == 0 ) {
+    my $allow = $iSetting->get('BBS_IMG_ALLOWED_EXT') || '';
+    my @ext = split ',', $allow;
+    if ( @ext == 0 or $ext[0] eq '' ) {
         @ext = qw(jpg gif png);
     }
 
@@ -1184,7 +1210,8 @@ sub _acceptable {
             return 1;
         }
     }
-    0;
+
+    return 0;
 }
 
 sub redirect_success {
@@ -1192,31 +1219,28 @@ sub redirect_success {
     my $iBBS     = $iApp->{__bbs};
     my $iConfig  = $iApp->{_config};
     my $iRequest = $iApp->{_request};
+    my $data = { ok => 1, error => '', errstr => '' };
 
     if ( $iRequest->param('js') ) {
         $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
-        $iRequest->print(
-            $iRequest->get_json(
-                {   ok     => 1,
-                    error  => '',
-                    errstr => ''
-                }
-            )
-        );
+        $iRequest->print( $iRequest->get_json($data) );
+    }
+    elsif ( $iRequest->param('xml') ) {
+        $iRequest->send_http_header( 'application/xml', 'UTF-8' );
+        $iRequest->print( $iRequest->get_xml( { response => $data } ) );
     }
     else {
-        require Img0ch::Metadata;
-        my $iTemplate = Img0ch::Template->new(
-            $iBBS,
+        my $iTemplate = $iBBS->get_template_instance(
             {   file    => 'redirect',
                 request => $iRequest,
                 setting => $iApp->{__setting},
             }
         );
         my $is_mobile = $iApp->{_serial} ? 1 : 0;
+        my $main_banner = $iBBS->get_metadata_instance()->main_banner();
         $iTemplate->param(
             {   ( map { %{$_} } @{ $iApp->{__template_tag_redirect} } ),
-                'Banner'       => Img0ch::Metadata->new($iBBS)->main_banner(),
+                'Banner'       => $main_banner,
                 'IsMobile'     => $is_mobile,
                 'KEY'          => $iApp->{__key},
                 'RedirectWait' => ( $iConfig->get_int('RedirectWait') || 5 ),
@@ -1231,7 +1255,8 @@ sub redirect_success {
             : undef
         );
     }
-    1;
+
+    return 1;
 }
 
 sub redirect_error {
@@ -1241,13 +1266,13 @@ sub redirect_error {
     my $iObject  = $iApp->{__bbs} || $iKernel;
     my $iRequest = $iApp->{_request};
 
-    require Img0ch::Error;
+    defined &{'Img0ch::Error::new'} or require Img0ch::Error;
     my $key = $iApp->{__key} || $iRequest->key();
     my $iError = Img0ch::Error->new( $iObject, $key, $iApp->{_ip_int} );
     my $error = $iApp->{__error} || 'UNKNOWN_ERROR';
     my $long = $iError->get($error);
 
-    $iError->record();
+    $iError->add();
     while ( my ( $subs, $value ) = each %{ $iApp->{__error_args} } ) {
         $long =~ s/{!$subs!}/$value/gxms;
     }
@@ -1255,29 +1280,33 @@ sub redirect_error {
     my $charset = $iKernel->get_encoding(1);
     my $ip      = $iApp->{_host} || $iApp->{_ip} || $iRequest->ip();
     my $name    = $iApp->{__param_FROM}
-        || $iRequest->param_multibyte( 'FROM', $charset );
+        || $iKernel->get_encoded_str( $iRequest->param('FROM'), $charset );
     my $mail = $iApp->{__param_mail}
-        || $iRequest->param_multibyte( 'mail', $charset );
+        || $iKernel->get_encoded_str( $iRequest->param('mail'), $charset );
     my $message = $iApp->{__param_MESSAGE}
-        || $iRequest->param_multibyte( 'MESSAGE', $charset );
+        || $iKernel->get_encoded_str( $iRequest->param('MESSAGE'), $charset );
+    my $data = {
+        ok     => 0,
+        error  => $error,
+        errstr => $iKernel->get_encoded_str( $long, 'utf8' ),
+    };
     $callback and $callback->( $iApp, $long );
 
     if ( $iRequest->param('js') ) {
-        require Unicode::Japanese;
         $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
-        $long =~ tr/\r//d;
-        my $icode = Unicode::Japanese->getcode($long);
-        $iRequest->print(
-            $iRequest->get_json(
-                {   ok     => 0,
-                    error  => $error,
-                    errstr => Unicode::Japanese->new( $long, $icode )->get()
-                }
-            )
-        );
+        $iRequest->print( $iRequest->get_json($data) );
+    }
+    elsif ( $iRequest->param('xml') ) {
+        $iRequest->send_http_header( 'application/xml', 'UTF-8' );
+        $iRequest->print( $iRequest->get_xml( { response => $data } ) );
     }
     else {
-        require Img0ch::Template;
+        my $iSetting = $iApp->{__setting};
+        $iApp->trip(
+            \$name,
+            ( $iSetting ? $iSetting->get_int('BBS_TRIPCOLUMN') : 10 ),
+            $iConfig->get('multibyte.TRUE_TRIP'),
+        );
         my $iTemplate = Img0ch::Template->new(
             $iObject,
             {   file => ( $template || 'error' ),
@@ -1304,7 +1333,8 @@ sub redirect_error {
         $iRequest->send_http_header( 'text/html', $charset );
         $iTemplate->flush($filter);
     }
-    0;
+
+    return 0;
 }
 
 sub _update_index_thread {
@@ -1355,7 +1385,8 @@ sub _update_index_thread {
             'isFirst' => 0,
             };
     }
-    1;
+
+    return 1;
 }
 
 sub _update_index_anchors {
