@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Mobile.pm 850 2007-06-23 11:39:18Z hikarin $
+# $Id: Mobile.pm 1188 2007-09-25 14:18:57Z hikarin $
 #
 
 package Img0ch::App::Mobile;
@@ -88,16 +88,12 @@ sub load_thread {
     $option->{noname}    = $omit_name;
     $option->{thumbnail} = $thumbnail;
 
-    my $name = $iApp->get_param('FROM');
-    if ($name) {
-        require Unicode::Japanese;
-        $name = Unicode::Japanese->new( $name, 'auto' )->sjis();
-    }
+    my $iKernel = $iApp->{_kernel};
+    my $name    = $iApp->get_param('FROM');
+    $name and $name = $iKernel->get_encoded_str($name);
+
     my $mail = $iApp->get_param('mail');
-    if ($mail) {
-        require Unicode::Japanese;
-        $mail = Unicode::Japanese->new( $mail, 'auto' )->sjis();
-    }
+    $mail and $mail = $iKernel->get_encoded_str($mail);
 
     my ( $raw_noa, $raw_noc ) = ( $raw, $raw );
     $raw_noa =~ s/a//gxms;
@@ -140,10 +136,8 @@ sub load_subject {
     my $iRequest = $iApp->{_request};
     my $iSetting = $iApp->{_setting};
 
-    require Img0ch::Subject;
-    require Img0ch::Metadata;
-    my $iMeta    = Img0ch::Metadata->new($iBBS);
-    my $iSubject = Img0ch::Subject->new($iBBS);
+    my $iMeta    = $iBBS->get_metadata_instance();
+    my $iSubject = $iBBS->get_subject_instance();
     $iSubject->load();
 
     my $word  = $iRequest->param('s');
@@ -182,9 +176,7 @@ sub load_subject {
     my $count = @{$read_subject_stack};
     my $prev = ( $count ? $start : $iSubject->count() ) - $floatable;
 
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        $iBBS,
+    my $iTemplate = $iBBS->get_template_instance(
         {   file    => 'i_threads',
             request => $iRequest,
             setting => $iSetting,
