@@ -14,13 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Note.pm 465 2007-04-08 13:01:09Z hikarin $
+# $Id: Note.pm 1220 2007-09-30 12:24:42Z hikarin $
 #
 
 package Img0ch::App::Note;
 
 use strict;
 use base qw(Img0ch::App::BBS);
+use Img0ch::Plugin::Module::Draft qw();
+use Img0ch::Plugin::Module::Note qw();
 
 sub new {
     my ( $iClass, $iKernel, @args ) = @_;
@@ -119,10 +121,9 @@ sub run {
 sub create_animation {
     my ( $iApp, $id ) = @_;
 
-    require Img0ch::Template;
+    my $iBBS      = $iApp->bbs();
     my $iRequest  = $iApp->request();
-    my $iTemplate = Img0ch::Template->new(
-        $iApp->bbs(),
+    my $iTemplate = $iBBS->get_template_instance(
         {   file    => 'note_animation',
             request => $iRequest,
             setting => $iApp->setting(),
@@ -133,16 +134,13 @@ sub create_animation {
     if (    $key = $iRequest->key()
         and $resno = $iRequest->param_int('resno') )
     {
-        require Img0ch::Plugin::Module::Note;
-        require Img0ch::Upload;
         my $iBBS    = $iApp->bbs();
         my $iNote   = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
-        my $iUpload = Img0ch::Upload->new( $iBBS, $key );
+        my $iUpload = $iBBS->get_upload_instance($key);
         ( undef, $width, $height, undef ) = @{ $iUpload->get($id) };
         $magic = $iNote->get($resno)->{applet} || 'P';
     }
     elsif ( $id = $iRequest->param_int('draft') ) {
-        require Img0ch::Plugin::Module::Draft;
         my $iDraft = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
         $magic  = $iDraft->get_applet_magic($id) || 'P';
         $width  = $iDraft->get_width($id);
@@ -167,12 +165,10 @@ sub create_animation {
 sub create_canvas {
     my ( $iApp, $id, $requireLoadImage, $edit_pass ) = @_;
 
-    require Img0ch::Template;
     my $template_param = $iApp->update_subback( $iApp->bbs(), 0, 1 );
     my $iBBS           = $iApp->bbs();
     my $iRequest       = $iApp->request();
-    my $iTemplate      = Img0ch::Template->new(
-        $iBBS,
+    my $iTemplate      = $iBBS->get_template_instance(
         {   file    => 'note_canvas',
             request => $iRequest,
             setting => $iApp->setting(),
@@ -193,8 +189,7 @@ sub create_canvas {
     my ( $width, $height )
         = ( $iRequest->param_int('width'), $iRequest->param_int('height') );
     if ($requireLoadImage) {
-        require Img0ch::Upload;
-        my $iUpload = Img0ch::Upload->new( $iBBS, $key );
+        my $iUpload = $iBBS->get_upload_instance($key);
         ( $ext, $width, $height, undef ) = @{ $iUpload->get($id) };
     }
 
@@ -223,15 +218,13 @@ sub create_postform {
     my ($iApp) = @_;
     my $template_param = $iApp->update_subback( $iApp->bbs(), 0, 1 );
     my $iRequest       = $iApp->request();
-    my $iTemplate      = Img0ch::Template->new(
-        $iApp->bbs(),
+    my $iTemplate      = $iApp->bbs()->get_template_instance(
         {   file    => 'note_form',
             request => $iRequest,
             setting => $iApp->setting(),
         }
     );
 
-    require Img0ch::Plugin::Module::Draft;
     $iRequest->init( $iApp->config() );
     my $iNote = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
     my $id    = $iRequest->param_int('draft') || 0;
@@ -252,7 +245,6 @@ sub create_confirm_password {
     $key   ||= $iRequest->key();
     $resno ||= $iRequest->param_int('resno');
 
-    require Img0ch::Plugin::Module::Note;
     my $iBBS   = $iApp->bbs();
     my $iNote  = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
     my $data   = $iNote->get($resno);
@@ -267,9 +259,7 @@ sub create_confirm_password {
         $failed = 1;
     }
 
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        $iApp->bbs(),
+    my $iTemplate = $iApp->bbs()->get_template_instance(
         {   file    => 'note_confirm',
             request => $iRequest,
             setting => $iApp->setting(),
@@ -299,14 +289,12 @@ sub load_pch {
     if (    my $key = $iRequest->key()
         and my $resno = $iRequest->param_int('resno') )
     {
-        require Img0ch::Plugin::Module::Note;
         my $iBBS = $iApp->bbs();
         my $iNote = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
         $file = "${resno}.pch";
         $pch  = $iNote->get($resno)->{animation};
     }
     elsif ( my $id = $iRequest->param_int('draft') ) {
-        require Img0ch::Plugin::Module::Draft;
         my $iDraft = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
         $file = "${id}.pch";
         $pch  = $iDraft->get_animation($id);
@@ -330,7 +318,6 @@ sub load_canvas {
     if (    my $key = $iRequest->param_int('key')
         and my $resno = $iRequest->param('resno') )
     {
-        require Img0ch::Plugin::Module::Note;
         my $iBBS = $iApp->bbs();
         my $iNote = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
         $image = $iNote->get_image($resno);
@@ -339,7 +326,6 @@ sub load_canvas {
         $type  = 'image/' . $ext;
     }
     elsif ( my $id = $iRequest->param_int('draft') ) {
-        require Img0ch::Plugin::Module::Draft;
         my $iDraft = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
         $image = $iDraft->get_image($id);
         $ext   = $iDraft->get_image_type($id);
@@ -361,13 +347,12 @@ sub save_draft {
     my $iRequest = $iApp->request();
     $iRequest->init( $iApp->config() );
 
-    require Img0ch::Plugin::Module::Draft;
     my $iDraft  = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
     my $now     = $iRequest->now();
     my $ellapse = $iDraft->get_ellapse() + $iRequest->param_int('timer');
     my $expires = $iConfig->get_int('DraftExpire') || 86400;
 
-    require Img0ch::Upload;
+    defined &{'Img0ch::Upload::get_dimensions'} or require Img0ch::Upload;
     my ( $width, $height )
         = Img0ch::Upload->get_dimensions( $iRequest->tempfile() );
 
@@ -391,7 +376,6 @@ sub remove_draft {
     my $iRequest = $iApp->request();
     $iRequest->init( $iApp->config() );
 
-    require Img0ch::Plugin::Module::Draft;
     my $iDraft = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
     my $id     = $iRequest->param_int('draft');
     $iDraft->remove($id);
@@ -415,16 +399,13 @@ sub search_drafts {
         return $iTemplate;
     }
 
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        $iApp->bbs(),
+    my $iTemplate = $iApp->bbs()->get_template_instance(
         {   file    => 'note_drafts',
             request => $iRequest,
             setting => $iApp->setting(),
         }
     );
 
-    require Img0ch::Plugin::Module::Draft;
     my $iNote = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
     my $stack = [];
 
@@ -508,7 +489,6 @@ sub capture {
         }
     }
     elsif ( my $id = $iRequest->param('noteID') ) {
-        require Img0ch::Plugin::Module::Draft;
         my $iDraft = Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
         my $image  = $iDraft->get_image($id);
         my $ext    = $iDraft->get_image_type($id);
@@ -534,15 +514,13 @@ sub update_note {
     my $key      = $iRequest->key();
     my $resno    = $iRequest->param_int('resno');
 
-    require Img0ch::Plugin::Module::Note;
     my $iBBS  = $iApp->bbs();
     my $iNote = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
     my $data  = $iNote->get($resno);
     my $ext   = $data->{type};
     my $edit  = $iRequest->param('editpass');
     if ( $edit eq $data->{pass} ) {
-        require Img0ch::Upload;
-        my $iUpload = Img0ch::Upload->new( $iBBS, $key );
+        my $iUpload = $iBBS->get_upload_instance($key);
         if ( -w $iUpload->path( $resno, $ext ) ) {
             $iUpload->set( $iRequest->tempfile(), $resno, $ext );
             $iUpload->set_remove_password( $iRequest->param('pass') );
@@ -590,7 +568,12 @@ BEGIN {
             return $iApp->{$attr};
             }
     }
-    for my $method (qw(agent fh ip ip_int msec now)) {
+    for my $method (
+        qw(agent fh get_app_uri get_device_id
+        get_remote_host is_mobile_device
+        ip ip_int msec now path_info query)
+        )
+    {
         no strict 'refs';
         *{"${pkg}::${method}"} = sub { $_[0]->{__orig}->$method };
     }
@@ -644,10 +627,6 @@ sub get_header { shift->{__orig}->get_header(@_) }
 
 sub set_header { shift->{__orig}->set_header(@_) }
 
-sub query { $_[0]->{__orig}->query() }
-
-sub path_info { $_[0]->{__orig}->path_info() }
-
 sub is_uploadable {1}
 
 sub fsize { $_[0]->{__fsize} }
@@ -668,7 +647,7 @@ sub set_param_internal {
 sub set_image_to_file_internal {
     my ( $iRequest, $image, $suffix ) = @_;
     caller() eq 'Img0ch::App::Note' or return;
-    require File::Temp;
+    defined &{'File::Temp::tempfile'} or require File::Temp;
     my ( $fh, $temp )
         = File::Temp::tempfile( UNLINK => 1, SUFFIX => ".${suffix}" );
     binmode $fh;
