@@ -14,12 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 850 2007-06-23 11:39:18Z hikarin $
+# $Id: Read.pm 1481 2007-10-24 14:13:30Z hikarin $
 #
 
 package Img0ch::App::Read;
 
 use strict;
+use Img0ch::BBS qw();
+use Img0ch::Template qw();
+use Img0ch::Thread qw();
 
 BEGIN {
     my $pkg = __PACKAGE__;
@@ -100,7 +103,6 @@ sub init {
     $iRequest->init($iConfig);
     $iApp->_parse_from_request( $iConfig, $iRequest, $mobile );
 
-    require Img0ch::BBS;
     my $iBBS = Img0ch::BBS->new( $iApp->{_kernel},
         { bbs => $iApp->{_param_bbs}, } );
     if ( !$iBBS->get_id() ) {
@@ -111,15 +113,12 @@ sub init {
 
     my $key = $iApp->{_param_key};
 
-    require Img0ch::Setting;
-    my $iSetting = Img0ch::Setting->new($iBBS);
-    $iSetting->load();
-    $iApp->{_setting} = $iSetting;
+    $iApp->{_setting} = $iBBS->get_setting_instance();
     $iApp->{__now}    = $iRequest->now();
 
-    require Img0ch::Thread;
-    my $iThread = Img0ch::Thread->new( $iBBS, $key );
-    my $count = $iThread->load();
+    my $iThread = $iBBS->get_thread_instance(0);
+    $iThread->set_key($key);
+    my $count = $iThread->count();
     ( !$count and !$mobile ) and return 0;
 
     $iApp->{__agent}        = $iRequest->agent();
@@ -128,8 +127,7 @@ sub init {
     $iApp->_normalize($mobile);
 
     if ( !$iConfig->get( $option->{disable} ) ) {
-        require Img0ch::Plugin;
-        my $iPlugin = Img0ch::Plugin->new( $iBBS, $key );
+        my $iPlugin = $iBBS->get_plugin_instance($key);
         $iPlugin->do( $option->{type}, $iApp ) or return 0;
         $iApp->{_plugin} = $iPlugin;
     }
@@ -170,8 +168,7 @@ sub load_thread {
         $iThread->enable_xhtml_break();
     }
 
-    require Img0ch::Plugin;
-    my $iPlugin = $iApp->{_plugin} || Img0ch::Plugin->new( $iBBS, $key );
+    my $iPlugin = $iApp->{_plugin} || $iBBS->get_plugin_instance($key);
     my $plugin = $iPlugin->iterator( $option->{type}, sub { ${ $_[3] } } );
     my $read_thread_stack = [];
     my $read_range        = $iApp->{__range_read};
@@ -263,11 +260,8 @@ sub load_thread {
     $reader = join( '/',
         $server, $renderer, $iBBS->get_name(), $iApp->{_param_key} );
 
-    require Img0ch::Metadata;
-    require Img0ch::Template;
-    my $iMeta     = Img0ch::Metadata->new($iBBS);
-    my $iTemplate = Img0ch::Template->new(
-        $iBBS,
+    my $iMeta     = $iBBS->get_metadata_instance();
+    my $iTemplate = $iBBS->get_template_instance(
         {   file    => $option->{template},
             request => $iRequest,
             setting => $iSetting,
@@ -349,16 +343,17 @@ sub redirect_error {
 
     if ($iBBS) {
         $archive_path = $iBBS->url('kako');
-        require Img0ch::Archive;
-        my $iArchive = Img0ch::Archive->new($iBBS);
+        my $iArchive = $iBBS->get_archive_instance();
         ( $subject, $res_count ) = @{ $iArchive->get($key) };
         $res_count and $archive_found = 1;
 
-        require Img0ch::Pool::Subject;
+        defined &{'Img0ch::Pool::Subject::new'}
+            or require Img0ch::Pool::Subject;
         my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
         ( $subject, $res_count ) = @{ $iPSubject->get($key) };
         if ($res_count) {
-            require Img0ch::Pool::Thread;
+            defined &{'Img0ch::Pool::Thread::new'}
+                or require Img0ch::Pool::Thread;
             my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
             $iPThread->load();
             my @load_reses = (1);
@@ -383,13 +378,12 @@ sub redirect_error {
             $pool_found = 1;
         }
 
-        require Img0ch::Metadata;
-        my $iMeta = Img0ch::Metadata->new($iBBS);
+        my $iMeta = $iBBS->get_metadata_instance();
         $banner = $iMeta->main_banner();
         $meta   = $iMeta->meta();
     }
     else {
-        require Img0ch::Error;
+        defined &{'Img0ch::Error::new'} or require Img0ch::Error;
         my $ip = $iRequest->ip_int();
         my $iError = Img0ch::Error->new( $iKernel, $key, $ip );
         $iError->record();
@@ -424,7 +418,6 @@ sub redirect_error {
         return $template_parameters;
     }
     else {
-        require Img0ch::Template;
         my $iTemplate = Img0ch::Template->new(
             ( $iBBS || $iKernel ),
             {   file    => 'not_found',
