@@ -14,18 +14,39 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 387 2007-03-20 13:59:10Z hikarin $
+# $Id: BBS.pm 1361 2007-10-14 14:58:58Z hikarin $
 #
 
 package Img0ch::BBS;
 
 use strict;
 
+BEGIN {
+    my $self    = __PACKAGE__;
+    my @classes = qw(
+        Archive Cap Log Metadata Plugin Setting
+        Subject Template Thread Upload
+    );
+    for my $class_name (@classes) {
+        my $file   = 'Img0ch/' . $class_name . '.pm';
+        my $class  = 'Img0ch::' . $class_name;
+        my $method = 'get_' . lcfirst($class_name) . '_instance';
+        no strict 'refs';
+        *{"${self}::${method}"} = sub {
+            defined &{"${class}::new"} or require $file;
+            my $object  = $class->new(@_);
+            my $coderef = $object->can('load');
+            $coderef and $coderef->($object);
+            return $object;
+            }
+    }
+}
+
 sub new {
     my ( $iClass, $iKernel, $hash ) = @_;
     my $iConfig = $iKernel->get_config();
     my $iRepos  = $iKernel->get_repos( $iKernel->get_repos_path('common') );
-    my ( $dir, $id ) = ( ($hash->{bbs} || ''), ($hash->{id} || '0') );
+    my ( $dir, $id ) = ( ( $hash->{bbs} || '' ), ( $hash->{id} || '0' ) );
 
     if ( $iConfig->get('compatible.bbs') ) {
         require Img0ch::Compat::BBS;
@@ -263,6 +284,166 @@ $joined_url
 
 引数から掲示板のディレクトリの含めたURLを作成します。
 
+=head2 get_archive_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iArchive
+
+=back
+
+I<Img0ch::Archive>クラスを生成し、I<Img0ch::Archive>のインスタンスを返します。
+
+=head2 get_cap_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iCap
+
+=back
+
+I<Img0ch::Cap>クラスを生成し、I<Img0ch::Cap>のインスタンスを返します。
+
+=head2 get_log_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iLog
+
+=back
+
+I<Img0ch::Log>クラスを生成し、I<Img0ch::Log>のインスタンスを返します。
+
+=head2 get_metadata_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iMeta
+
+=back
+
+I<Img0ch::Metadata>クラスを生成し、I<Img0ch::Metadata>のインスタンスを返します。
+
+=head2 get_plugin_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iPlugin
+
+=back
+
+I<Img0ch::Plugin>クラスを生成し、I<Img0ch::Plugin>のインスタンスを返します。
+
+=head2 get_setting_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iSetting
+
+=back
+
+I<Img0ch::Setting>クラスを生成し、I<Img0ch::Setting>のインスタンスを返します。
+
+=head2 get_subject_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iSubject
+
+=back
+
+I<Img0ch::Subject>クラスを生成し、I<Img0ch::Subject>のインスタンスを返します。
+
+=head2 get_template_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iTemplate
+
+=back
+
+I<Img0ch::Template>クラスを生成し、I<Img0ch::Template>のインスタンスを返します。
+
+=head2 get_thread_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iThread
+
+=back
+
+I<Img0ch::Thread>クラスを生成し、I<Img0ch::Thread>のインスタンスを返します。
+
+=head2 get_upload_instance
+
+=over 4
+
+=item Arguments
+
+@argument_to_construct
+
+=item Return Value
+
+$iUpload
+
+=back
+
+I<Img0ch::Upload>クラスを生成し、I<Img0ch::Upload>のインスタンスを返します。
+
 =head1 AUTHOR
 
 hkrn E<lt>hikarin@users.sourceforge.jpE<gt>
