@@ -14,30 +14,26 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Cap.pm 363 2007-03-16 15:11:10Z hikarin $
+# $Id: Cap.pm 1246 2007-10-02 14:10:31Z hikarin $
 #
 
 package Img0ch::Compat::Cap;
 
 use strict;
+use Zeromin::Cap qw();
 
 sub update {
     my ($iBBS) = @_;
 
-    require Unicode::Japanese;
     my $iKernel  = $iBBS->get_kernel();
     my $zCap     = Zeromin::Cap->new($iBBS);
     my $base     = $iKernel->get_config()->get('BBSPath');
     my $encoding = $iKernel->get_encoding(1);
-    my $unijp    = Unicode::Japanese->new();
 
     my $cgroup = $base . '/test/info/groupc.cgi';
     if ( -r $cgroup ) {
-        require Img0ch::BBS;
-        local ( $!, *FH );
-        open *FH, "<${cgroup}"    ## no critic
-            or $iKernel->throw_io_exception($cgroup);
-        while ( my $line = <FH> ) {
+        my $fh = $iKernel->get_read_file_handle($cgroup);
+        while ( my $line = <$fh> ) {
             chomp $line;
             my ( $name, $bbs_dir, undef, $rt ) = split '<>', $line;
             $zCap->get_group_id($name) and next;
@@ -47,32 +43,32 @@ sub update {
                 = Img0ch::BBS->new( $iKernel, { bbs => $bbs_dir } )->get_id();
             _cgroup_update_privilege( \$privilege, $rt );
             $zCap->add_group(
-                {   bbs       => $bbs_id,
-                    name      => $unijp->set( $name, 'sjis' )->get(),
+                {   bbs => $bbs_id,
+                    name =>
+                        $iKernel->get_encoded_str( $name, 'utf8', 'sjis' ),
                     privilege => $privilege
                 }
             );
         }
-        close *FH or $iKernel->throw_io_exception($cgroup);
+        close $fh or $iKernel->throw_io_exception($cgroup);
     }
 
     my $cap = $base . '/test/info/caps.cgi';
     if ( -r $cap ) {
-        local ( $!, *FH );
-        open *FH, "<${cap}"    ## no critic
-            or $iKernel->throw_io_exception($cap);
-        while ( my $line = <FH> ) {
+        my $fh = $iKernel->get_read_file_handle($cap);
+        while ( my $line = <$fh> ) {
             chomp $line;
             my ( undef, $cname, $pass, $gname, undef ) = split '<>', $line;
-            $gname = $unijp->set( $gname, 'sjis' )->get();
+            $gname = $iKernel->get_encoded_str( $gname, 'utf8', 'sjis' );
             $zCap->add(
-                {   name => $unijp->set( $cname, 'sjis' )->$encoding,
+                {   name =>
+                        $iKernel->get_encoded_str( $cname, undef, 'sjis' ),
                     pass => $pass,
                     gid  => $zCap->get_group_id($gname)
                 }
             );
         }
-        close *FH or $iKernel->throw_io_exception($cap);
+        close $fh or $iKernel->throw_io_exception($cap);
     }
 
     $zCap->save();
