@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Log.pm 922 2007-07-26 13:35:06Z hikarin $
+# $Id: Log.pm 1447 2007-10-21 13:24:54Z hikarin $
 #
 
 package Img0ch::Log;
@@ -30,6 +30,7 @@ sub new {
     bless {
         _bbs    => $iBBS->get_name(),
         _i0_bbs => $iBBS,
+        _kernel => $iKernel,
         _key    => $key,
         __log   => [],
         _rs     => $iKernel->get_repos_nocache($repos_path),
@@ -55,12 +56,12 @@ sub save {
         $iRepos->set( "${prefix}.date",   $date );
         $iRepos->set( "${prefix}.ip",     $ip );
         $iRepos->set( "${prefix}.serial", $serial );
-        $iRepos->set_binary( "${prefix}.agent", $agent );
+        $iRepos->set_binary( "${prefix}.agent", substr( $agent, 0, 255 ) );
     }
 
     @{ $iLog->{__log} } = ();
     $iRepos->save();
-    1;
+    return 1;
 }
 
 sub get {
@@ -128,14 +129,13 @@ sub search {
     my ( $iLog, $ip_or_serial ) = @_;
     $ip_or_serial or return [];
 
-    require Img0ch::Subject;
     my $iBBS     = $iLog->{_i0_bbs};
-    my $iSubject = Img0ch::Subject->new($iBBS);
+    my $iSubject = $iBBS->get_subject_instance();
     my $ret      = [];
     $iSubject->load();
 
     for my $key ( @{ $iSubject->to_array() } ) {
-        my ( $subject, $res )  = @{ $iSubject->get($key) };
+        my ( $subject, $res ) = @{ $iSubject->get($key) };
         my $iLog = Img0ch::Log->new( $iBBS, $key );
         for ( my $i = 1; $i <= $res; $i++ ) {
             my ( $date, $ip, $serial, $agent ) = @{ $iLog->get($i) };
@@ -145,7 +145,8 @@ sub search {
                 push @$ret, [ $key, $i, $date, $ip, '', $agent, $subject ];
             }
             elsif ( $serial eq $ip_or_serial ) {
-                push @$ret, [ $key, $i, $date, '', $serial, $agent, $subject ];
+                push @$ret,
+                    [ $key, $i, $date, '', $serial, $agent, $subject ];
             }
         }
     }
