@@ -14,15 +14,16 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Maple.pm 972 2007-08-21 15:02:57Z hikarin $
+# $Id: Maple.pm 1491 2007-10-25 13:17:24Z hikarin $
 #
 
 package Img0ch::Maple;
 
 use strict;
+use Fcntl qw(:DEFAULT :flock);
 
-$Img0ch::Maple::RCS_ID   = '$Id: Maple.pm 972 2007-08-21 15:02:57Z hikarin $';
-$Img0ch::Maple::VERSION  = '2.1.17';
+$Img0ch::Maple::RCS_ID  = '$Id: Maple.pm 1491 2007-10-25 13:17:24Z hikarin $';
+$Img0ch::Maple::VERSION = '2.1.21';
 $Img0ch::Maple::revision = do {
     my @rv = $Img0ch::Maple::RCS_ID =~ /(\d+)/xms;
     $rv[0];
@@ -30,20 +31,57 @@ $Img0ch::Maple::revision = do {
 
 sub new {
     my ( $iClass, $iConfig ) = @_;
-    my $repos_type
-        = $iClass->get_repos_type( $iConfig->get('RepositoryType') );
-    require "Img0ch/Maple/${repos_type}.pm";    ## no critic
+    my $class = 'Img0ch::Maple::'
+        . $iClass->get_repos_type( $iConfig->get('RepositoryType') );
+    defined &{"${class}::new"} or $iClass->load_module($class);
     $ENV{TZ} ||= $iConfig->get('TimeZone') || 'JST-9';
 
     bless {
-        __cache  => {},
-        __config => $iConfig,
-        __repos  => "Img0ch::Maple::${repos_type}",
+        __flockf =>
+            ( $iConfig->get('io.should_lock') ? LOCK_EX : LOCK_EX | LOCK_NB ),
+        __cache   => {},
+        __config  => $iConfig,
+        __noflock => $iConfig->get('io.no_flock'),
+        __repos   => $class,
     }, $iClass;
 }
 
 sub DESTROY { }
 
+sub get_read_file_handle {
+    my ( $iMaple, $path ) = @_;
+
+    -e $path or return;
+    sysopen my $fh, $path, O_RDONLY or $iMaple->throw_io_exception($path);
+    $iMaple->{__noflock}
+        or flock $fh, LOCK_SH
+        or $iMaple->throw_io_exception($path);
+
+    return $fh;
+}
+
+sub get_write_file_handle {
+    my ( $iMaple, $path, $umask ) = @_;
+    my $flag = -e $path ? O_WRONLY | O_CREAT : O_WRONLY | O_EXCL | O_CREAT;
+    $umask ||= 0666;
+
+    sysopen my $fh, $path, $flag, $umask
+        or $iMaple->throw_io_exception($path);
+    $iMaple->{__noflock}
+        or flock $fh, $iMaple->{__flockf}
+        or $iMaple->throw_io_exception($path);
+    truncate $fh, 0 or $iMaple->throw_io_exception($path);
+
+    return $fh;
+}
+
+sub load_module {
+    my ( $iClass, $module ) = @_;
+    $module =~ s{::}{/}gxms;
+    $module .= '.pm';
+    return require $module;
+}
+
 my $unijp_charset_alias = {
     'sjis'        => 'sjis',
     'shiftjis'    => 'sjis',
@@ -78,11 +116,11 @@ sub get_encoding {
 
 sub get_encoded_str {
     my ( $iKernel, $str, $to, $from ) = @_;
-    $str or return '';
+    $str                                or return '';
+    defined $Unicode::Japanese::VERSION or require Unicode::Japanese;
 
-    require Unicode::Japanese;
     $to ||= '';
-    $to =~ tr/\-\_//;
+    $to =~ tr/\-\_//d;
     $to = $unijp_charset_alias->{$to} || $iKernel->get_encoding(1);
     if ( !$from ) {
         my $name = Unicode::Japanese->getcode($str);
@@ -91,6 +129,9 @@ sub get_encoded_str {
     }
 
     my $unijp = $iKernel->{__unijp} ||= Unicode::Japanese->new();
+    $from ||= '';
+    $from =~ tr/\-\_//d;
+    $from = $unijp_charset_alias->{$from} || $from;
     $unijp->set( $str, $from );
 
     return $unijp->conv($to);
@@ -138,23 +179,14 @@ sub intval {
 sub revision {$Img0ch::Maple::revision}
 
 sub get_repos {
-    my ( $iMaple, $path ) = @_;
-    my $iRepos = $iMaple->{__cache}->{$path};
-    $iRepos and return $iRepos;
-
-    $iRepos = $iMaple->{__repos}->new( $iMaple, $path );
-    $iRepos->load();
-    $iMaple->{__cache}->{$path} = $iRepos;
-    return $iRepos;
-}
-
-sub get_repos_nocache {
     my ( $iMaple, $path ) = @_;
     my $iRepos = $iMaple->{__repos}->new( $iMaple, $path );
     $iRepos->load();
     return $iRepos;
 }
 
+*get_repos_nocache = \&get_repos;
+
 sub get_repos_path {
     my ( $iMaple, $path ) = @_;
     my $iConfig = $iMaple->get_config();
@@ -178,9 +210,9 @@ sub rollback_transaction {
 }
 
 sub create_repository_subdirs {
-    my ( $time, $filename, $iObject ) = @_;
+    my ( $time, $filename, $iObject, $truncate ) = @_;
 
-    $time ||= 0;
+    $time or return '';
     my ( undef, undef, undef, $day, $month, $year ) = localtime($time);
 
     $year  += 1900;
@@ -189,10 +221,14 @@ sub create_repository_subdirs {
         = $iObject->get_repos_path( join '/', $year, $month, $day, $time,
         $filename );
     my $repos_file_dir = $repos_file_path;
-    $repos_file_dir =~ s{/$filename.\w+\z}{}xms;
+    $repos_file_dir =~ s{/$filename\.\w+\z}{}xms;
+    if ($truncate) {
+        $repos_file_dir  =~ s{/$time\z}{}xms;
+        $repos_file_path =~ s{/$time/($filename\.\w+)\z}{/$1}xms;
+    }
 
     if ( !-d $repos_file_dir ) {
-        require File::Path;
+        defined $File::Path::VERSION or require File::Path;
         my $iKernel
             = $iObject->isa('Img0ch::BBS')
             ? $iObject->get_kernel()
@@ -243,12 +279,7 @@ sub get_application_modules { [ values %{$module_by_script} ] }
 sub get_module_by_script { $module_by_script->{ $_[1] } || '' }
 
 sub load_application_modules {
-    my @modules = values %{$module_by_script};
-    for my $app (@modules) {
-        $app .= '.pm';
-        $app =~ s{::}{/}gxms;
-        require $app;
-    }
+    map { __PACKAGE__->load_module($_) } values %{$module_by_script};
     return;
 }
 
@@ -353,6 +384,28 @@ I<DefaultCharset>が指定されていなければShift_JISを、
 $return_as_unicode_japanese_charsetが設定されていれば
 sjisを返します。
 
+=head2 get_encoded_str
+
+=over 4
+
+=item Arguments
+
+$string_to_encode, $to_charset, $from_charset
+
+=item Return Value
+
+$encoded_string
+
+=back
+
+I<$string_to_encode>からエンコードセットI<$to_charset>に
+変換した文字列を返します。
+I<$from_charset>が指定されていなければI<$string_to_encode>から
+エンコードセットの自動判定を行います。I<$to_charset>が指定されていなければ
+I<get_encoding()>から現在のエンコードセットを求め、それに変換します。
+I<$from_charset>とI<$to_charset>が同一の場合はI<$string_to_encode>
+そのものを返します。
+
 =head2 escape_html_entities
 
 =over 4
@@ -496,6 +549,42 @@ none
 
 Img0ch::App::*のモジュールを全て読み込みます。
 
+=head2 get_read_file_handle
+
+=over 4
+
+=item Arguments
+
+$file_path
+
+=item Return Value
+
+$file_handle
+
+=back
+
+I<$file_path>を読み込み専用で開き、そのファイルハンドルを返します。
+ファイルが存在し無い場合はI<undef>を返します。
+I/Oエラーが発生すると例外を発行します。
+
+=head2 get_write_file_handle
+
+=over 4
+
+=item Arguments
+
+$file_path, $umask_value
+
+=item Return Value
+
+$file_handle
+
+=back
+
+I<$file_path>を書き込み専用で開き、そのファイルハンドルを返します。
+I<$umask_value>が存在する場合はumask値を設定します。
+I/Oエラーが発生すると例外を発行します。
+
 =head2 get_repos
 
 =over 4
@@ -548,6 +637,21 @@ I<RepositoryType>からモジュールを読み込めるようにする値を返
 一致する値が存在しない場合I<Simple(Img0ch::Maple::Simple)>を返します。
 この関数はバージョンが2.1.x-3.xでのみ使用可能です。
 
+=head2 create_repository_subdirs
+
+=over 4
+
+=item Arguments
+
+$time, $filename, $iBBS_or_$iKernel
+
+=item Return Value
+
+none
+
+=back
+
+$timeに基づいてレポジトリのサブディレクトリを作成します。
 
 =head1 AUTHOR
 
