@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Config.pm 850 2007-06-23 11:39:18Z hikarin $
+# $Id: Config.pm 1266 2007-10-04 14:12:44Z hikarin $
 #
 
 package Img0ch::Plugin::BBS::RSS::Config;
@@ -24,7 +24,16 @@ use File::Basename qw();
 use XML::TreePP qw();
 
 sub register_hook {
-    return { render => \&render, };
+    return {
+        privilege => \&privilege,
+        render    => \&render,
+    };
+}
+
+sub privilege {
+    my ( $zPlugin, $zUser, $plugin_id, $iBBS, $key ) = @_;
+    $zUser->can_change_main_setting() or return 0;
+    return 1;
 }
 
 sub render {
@@ -32,7 +41,7 @@ sub render {
     my $file = File::Basename::dirname(__FILE__) . '/layout.xml';
     my $tree = XML::TreePP->new();
     $zPlugin->parse_from_hash( $tree->parsefile($file) );
-    return;
+    return 1;
 }
 
 1;
