@@ -14,13 +14,12 @@
 # *  limitations under the License.
 # */
 #
-# $Id: UTF8Dat.pm 615 2007-05-10 14:22:45Z hikarin $
+# $Id: UTF8Dat.pm 1193 2007-09-27 14:23:22Z hikarin $
 #
 
 package Img0ch::Plugin::BBS::UTF8Dat;
 
 use strict;
-use Unicode::Japanese qw();
 
 my $utf8bom = pack 'C*', ( 0xef, 0xbb, 0xbf );
 
@@ -30,34 +29,25 @@ sub sync {
     -r $from or return 1;
 
     my $iKernel  = $iApp->kernel();
-    my $unijp    = Unicode::Japanese->new('');
     my $compress = $iApp->setting()->get('BBS_COMPRESS_DAT');
-    _sync( $iKernel, $unijp, $from, $compress );
+    _sync( $iKernel, $from, $compress );
     return 1;
 }
 
 sub remove {
     my ( $iBBS, $plugin_id, $key ) = @_;
-
-    require Img0ch::Thread;
-    my $iThread = Img0ch::Thread->new( $iBBS, $key );
-    _remove( $iBBS->get_kernel(), $iThread->path() );
+    _remove( $iBBS->get_kernel(), $iBBS->get_thread_instance($key)->path() );
     return 1;
 }
 
-*batch = \&repair;
 sub repair {
     my ( $iBBS, $plugin_id, $info ) = @_;
-
-    require Img0ch::Thread;
-    require Unicode::Japanese;
     my $iKernel = $iBBS->get_kernel();
-    my $iThread = Img0ch::Thread->new($iBBS);
-    my $unijp   = Unicode::Japanese->new('');
+    my $iThread = $iBBS->get_thread_instance(0);
 
-    for my $key ( @{ $info->{recovered} } ) {
+    for my $key ( @{ $iBBS->get_subject_instance()->to_array() } ) {
         $iThread->set_key($key);
-        _sync( $iKernel, $unijp, $iThread->path(), 0 );
+        _sync( $iKernel, $iThread->path(), 0 );
     }
     for my $key ( @{ $info->{removed} } ) {
         $iThread->set_key($key);
@@ -68,11 +58,10 @@ sub repair {
 }
 
 sub _sync {
-    my ( $iKernel, $unijp, $from, $compress ) = @_;
+    my ( $iKernel, $from, $compress ) = @_;
     my $encoding = $iKernel->get_encoding(1);
-    local ( $!, *RFH, *WFH );
 
-    open *RFH, "<${from}" or $iKernel->throw_io_exception($from); ## no critic
+    my $rfh = $iKernel->get_read_file_handle($from);
     if ($compress) {
         my $to = $from . '.utf8.gz';
         my $gz = Compress::Zlib::gzopen( $to, 'w' )
@@ -82,23 +71,24 @@ sub _sync {
             Compress::Zlib::Z_DEFAULT_STRATEGY(),
         );
         $gz->gzwrite($utf8bom) or $iKernel->throw_io_exception($to);
-        while ( my $line = <RFH> ) {
-            $gz->gzwrite( $unijp->set( $line, $encoding )->get() )
+        while ( my $line = <$rfh> ) {
+            $gz->gzwrite(
+                $iKernel->get_encoded_str( $line, 'utf8', $encoding ) )
                 or $iKernel->throw_io_exception($to);
         }
         $gz->gzclose();
     }
     else {
-        my $to = $from . '.utf8';
-        open *WFH, ">${to}" or $iKernel->throw_io_exception($to); ## no critic
-        print {*WFH} $utf8bom or $iKernel->throw_io_exception($to);
-        while ( my $line = <RFH> ) {
-            print {*WFH} $unijp->set( $line, $encoding )->get()
+        my $to  = $from . '.utf8';
+        my $wfh = $iKernel->get_write_file_handle($to);
+        print ${wfh} $utf8bom or $iKernel->throw_io_exception($to);
+        while ( my $line = <$rfh> ) {
+            print $wfh $iKernel->get_encoded_str( $line, 'utf8', $encoding )
                 or $iKernel->throw_io_exception($to);
         }
-        close *WFH or $iKernel->throw_io_exception($to);
+        close $wfh or $iKernel->throw_io_exception($to);
     }
-    close *RFH or $iKernel->throw_io_exception($from);
+    close $rfh or $iKernel->throw_io_exception($from);
     return 1;
 }
 
