@@ -14,43 +14,40 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Image.pm 197 2007-02-08 13:34:17Z hikarin $
+# $Id: Image.pm 1481 2007-10-24 14:13:30Z hikarin $
 #
 
 package Img0ch::Plugin::Rewrite::Image;
 
 use strict;
-use Img0ch::Setting qw();
-use Img0ch::Upload qw();
 
 my $removeText = pack 'C*', 0x8d, 0xed, 0x8f, 0x9c;
+
 sub new {
     my ( $iClass, $iBBS, $key ) = @_;
     my $iConfig  = $iBBS->get_kernel()->get_config();
-    my $iSetting = Img0ch::Setting->new($iBBS);
-    my $iUpload  = Img0ch::Upload->new( $iBBS, $key );
-    my $freezed  = ( stat( $iBBS->path('img') ) )[2] & 07777 == 0700;
+    my $iSetting = $iBBS->get_setting_instance();
+    my $iUpload  = $iBBS->get_upload_instance($key);
     my $bbs      = $iBBS->get_name();
     my $lightbox = $iConfig->get('UploadImageLinkRelative') || 'lightbox[%s]';
-    my $url      = $iBBS->url('img');
-    my $ufm      = ( $iConfig->get('CGIServer')
-        || join( '/', $iConfig->get('Server'), 'test' ) )
-        . '/img0ch-ufm.cgi/' . $bbs . '/';
+    my $ufm
+        = Img0ch::Request->get_app_uri2($iConfig)
+        . '/img0ch-ufm.cgi/'
+        . $bbs . '/';
+    my $resizer
+        = Img0ch::Request->get_app_uri2($iConfig) . '/i.cgi/' . $bbs . '/';
 
     bless {
         __bbs              => $bbs,
-        __base_file_url    => $url,
         __cache_key        => $key,
-        __is_freezed       => $freezed,
         __i0_upload        => $iUpload,
         __link_relative    => $lightbox,
         __removed_mark     => $iUpload->removed_mark(),
+        __resizer_url      => $resizer,
         __thumbnail_max    => $iSetting->get('BBS_IMG_THUMBNAIL_MAX'),
         __thumbnail_width  => $iSetting->get('BBS_IMG_THUMBNAIL_X'),
         __thumbnail_height => $iSetting->get('BBS_IMG_THUMBNAIL_Y'),
         __ufm              => $ufm,
-        __use_fileseek     => $iConfig->get('UseFileSeek'),
-        __use_picto        => $iConfig->get('UsePicto'),
     }, $iClass;
 }
 
@@ -66,18 +63,23 @@ sub from_bbs {
     my ( $extension, $width, $height, $hash ) = @{ $iUpload->get($resno) };
     $hash or return;
 
-    my $max             = $iObject->{__thumbnail_max};
-    my $base_file_url   = join '/', $iObject->{__base_file_url}, $key;
-    my $file_name       = join '.', $resno, $extension;
-    my $file_url        = join '/', $base_file_url, $file_name;
+    my $max       = $iObject->{__thumbnail_max};
+    my $file_name = join '.', $resno, $extension;
+    my $file_url  = $iUpload->url( $resno, $extension );
 
-    if ( $iObject->{__is_freezed} ) {
+    if ( $hash eq $iObject->{__removed_mark} ) {
+        $$text =~ s{\A.*?$file_url.*?\(.+?\)<br(\s/)?>}
+            {<b>[NOT_FOUND]</b><br$1>}xms;
+    }
+    elsif ( $iUpload->is_freezed($resno) ) {
         $$text =~ s{\A.*?$file_url.*?\(.+?\)<br(\s/)?>}
             {<b>[UNDOWNLOADABLE]</b><br$1>}xms;
     }
-    elsif ( $hash eq $iObject->{__removed_mark} ) {
-        $$text =~ s{\A.*?$file_url.*?\(.+?\)<br(\s/)?>}
-            {<b>[NOT_FOUND]</b><br$1>}xms;
+    elsif ( $iUpload->have_download_password($resno) ) {
+        my $dlLink = '<b><a href="' . $iObject->{__ufm} . $key . '/';
+        $dlLink .= $resno . '">[REQUIRE_DOWNLOAD_KEY]</a></b>';
+        $$text =~ s{\A.*?$file_url.*?\((.+?)\)<br(\s/)?>}
+            {$dlLink($1)<br$2>}xms;
     }
     else {
         my ( $x, $y ) = ( 0, 0 );
@@ -101,32 +103,38 @@ sub from_bbs {
             )
         {
             my $format = join( '',
-                '<a href="', $file_url, '" class="i0_image" id="f', $key,
-                '_', $resno, '" rel="', $relative, '" title="',
-                $file_name, '"><b>[', $extension,  ']</b></a>' );
+                '<a href="',                $file_url,
+                '" class="i0_image" id="f', $key,
+                '_',                        $resno,
+                '" rel="',                  $relative,
+                '" title="',                $file_name,
+                '"><b>[',                   $extension,
+                ']</b></a>' );
             $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
                 {$format$removeLink($1)<br$2>}xms;
         }
-        elsif ( $iUpload->get_thumbnail_size(
-            $resno, \$scaled_width, \$scaled_height ) ) {
-            my $thumb_url =
-                "${base_file_url}/t${file_name}";
+        elsif (
+            $iUpload->get_thumbnail_size(
+                $resno, \$scaled_width, \$scaled_height
+            )
+            )
+        {
+            my $thumb_url   = $iUpload->url( "t${resno}", $extension );
             my $alternative = "${file_name} - ${width}x${height}";
-            my $format = join( '',
-                '<a href="', $file_url,
-                '" class="i0_image i0_thumbnail" id="f',
-                $bbs_dir,
-                '_',                $key,
-                '_',                $resno,
-                '" rel="',          $relative,
-                '" title="',        $alternative,
-                '"><img src="',     $thumb_url,
-                '" alt="',          $alternative,
-                '" width="',        $scaled_width,
-                '" height="',       $scaled_height,
-                '" id="i',          $bbs_dir,
-                '_',                $key,
-                '_',                $resno,
+            my $format      = join( '',
+                '<a href="',                             $file_url,
+                '" class="i0_image i0_thumbnail" id="f', $bbs_dir,
+                '_',                                     $key,
+                '_',                                     $resno,
+                '" rel="',                               $relative,
+                '" title="',                             $alternative,
+                '"><img src="',                          $thumb_url,
+                '" alt="',                               $alternative,
+                '" width="',                             $scaled_width,
+                '" height="',                            $scaled_height,
+                '" id="i',                               $bbs_dir,
+                '_',                                     $key,
+                '_',                                     $resno,
                 '" class="image" /></a>' );
             $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
                 {$format($1)$removeLink<br$2>}xms;
@@ -136,20 +144,20 @@ sub from_bbs {
             ( $scaled_width, $scaled_height )
                 = $iUpload->scale( $width, $height, $max_width, $max_height );
             my $alternative = "${file_name} - ${width}x${height}";
-            my $format = join( '',
-                '<a href="',    $file_url,
+            my $format      = join( '',
+                '<a href="',                $file_url,
                 '" class="i0_image" id="f', $bbs_dir,
-                '_',                $key,
-                '_',                $resno,
-                '" rel="',          $relative,
-                '" title="',        $alternative,
-                '"><img src="',     $file_url,
-                '" alt="',          $alternative,
-                '" width="',        $scaled_width,
-                '" height="',       $scaled_height,
-                '" id="i',          $bbs_dir,
-                '_',                $key,
-                '_',                $resno,
+                '_',                        $key,
+                '_',                        $resno,
+                '" rel="',                  $relative,
+                '" title="',                $alternative,
+                '"><img src="',             $file_url,
+                '" alt="',                  $alternative,
+                '" width="',                $scaled_width,
+                '" height="',               $scaled_height,
+                '" id="i',                  $bbs_dir,
+                '_',                        $key,
+                '_',                        $resno,
                 '" class="image" /></a>' );
             $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
                 {$format($1)$removeLink<br$2>}xms;
@@ -157,9 +165,12 @@ sub from_bbs {
         }
         else {
             my $format = join( '',
-                '<a href="', $file_url, '" class="i0_file" id="f',
-                $bbs_dir, '_', $key, '_', $resno, '">', '<b>[',
-                $extension,  ']</b></a>' );
+                '<a href="',               $file_url,
+                '" class="i0_file" id="f', $bbs_dir,
+                '_',                       $key,
+                '_',                       $resno,
+                '">',                      '<b>[',
+                $extension,                ']</b></a>' );
             $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
                 {$format$removeLink($1)<br$2>}xms;
         }
@@ -170,7 +181,7 @@ sub from_bbs {
 *from_read = \&from_bbs;
 
 sub from_mobile {
-    my ( $iObject, $key, $count, $resno, $text ) = @_;
+    my ( $iObject, $key, $count, $resno, $text, $param ) = @_;
     my $iUpload = $iObject->{__i0_upload};
     if ( $iObject->{__cache_key} ne $key ) {
         $iUpload->set_key($key);
@@ -182,14 +193,14 @@ sub from_mobile {
     $extension or return;
     my $file_url = join '/', $iUpload->url( $resno, $extension );
 
-    if ( $iObject->{__is_freezed} ) {
-        $$text =~ s{\A.*?$file_url.*?\((.+?)\)<br>}
-            {<b>[UNDOWNLOADABLE]</b><br>}xms;
-    }
-    elsif ( $hash eq $iObject->{__removed_mark} ) {
+    if ( $hash eq $iObject->{__removed_mark} ) {
         $$text =~ s{\A.*?$file_url.*?\((.+?)\)<br>}
             {<b>[NOT_FOUND]</b><br>}xms;
     }
+    elsif ( $iUpload->is_freezed($resno) ) {
+        $$text =~ s{\A.*?$file_url.*?\((.+?)\)<br>}
+            {<b>[UNDOWNLOADABLE]</b><br>}xms;
+    }
     else {
         my ( $x, $y ) = ( 0, 0 );
         my $is_image = (
@@ -197,36 +208,58 @@ sub from_mobile {
                 or $extension eq 'gif'
                 or $extension eq 'png'
         );
-        my $use_fseek = $iObject->{__use_fileseek};
         my $format;
-        if ( $iObject->{__use_picto} and $is_image ) {
+        if ($is_image) {
+            my $thumbnail_img_tag;
+            my ( $scaled_width, $scaled_height ) = ( 0, 0 );
+            if (    $param->{thumbnail}
+                and $resno > $count - $iObject->{__thumbnail_max}
+                and $iUpload->get_thumbnail_size(
+                    $resno, \$scaled_width, \$scaled_height
+                )
+                )
+            {
+                my $thumb_url = $iUpload->url( "t${resno}", $extension );
+                $thumbnail_img_tag = join '', '<img src=', $thumb_url,
+                    ' width=', $scaled_width, ' height=', $scaled_height,
+                    '><br>';
+            }
             my $url = $file_url;
             $url =~ s{\Ahttp://}{}xms;
             $format = join( '',
-                '<a href="http://pic.to/',
-                $url, '">[IMAGE:', uc($extension), '(PIC.TO)]</a>' );
+                $thumbnail_img_tag,
+                '[<a href="',
+                $iObject->{__resizer_url},
+                $key,
+                '/',
+                $resno,
+                '">IMAGE:',
+                uc($extension),
+                '</a>(<a href="',
+                $file_url,
+                '">DIRECT</a>:',
+                $width,
+                'x',
+                $height,
+                ')/<a href="http://pic.to/',
+                $url,
+                '">PIC.TO</a>/<a href="http://fileseek.net/getimg.html?',
+                $file_url,
+                '">FILESEEK.NET</a>]',
+            );
         }
-        elsif (
-            $use_fseek
-            and (  $extension eq 'mpg'
-                or $extension eq 'avi'
-                or $extension eq 'wmv'
-                or $extension eq 'wma'
-                or $extension eq 'mp3'
-                or $extension eq 'wav' )
-            )
+        elsif ($extension eq 'mpg'
+            or $extension eq 'avi'
+            or $extension eq 'wmv'
+            or $extension eq 'wma'
+            or $extension eq 'mp3'
+            or $extension eq 'wav' )
         {
             $format = join( '',
                 '<a href="http://fileseek.net/',
                 'getmovie.html?', $file_url, '">[MOVIE:', uc($extension),
                 '(FILESEEK.NET)]</a>' );
         }
-        elsif ( $use_fseek and $is_image ) {
-            $format = join( '',
-                '<a href="http://fileseek.net/getimg.html?',
-                $file_url, '">[IMAGE:', uc($extension),
-                '(FILESEEK.NET)]</a>' );
-        }
         elsif ( $width and $height ) {
             $format = join( '',
                 '<a href="',    $file_url, '">[IMAGE:',
