@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: NicoVideo.pm 197 2007-02-08 13:34:17Z hikarin $
+# $Id: NicoVideo.pm 1343 2007-10-09 13:22:38Z hikarin $
 #
 
 package Img0ch::Plugin::Rewrite::StreamService::NicoVideo;
@@ -25,23 +25,26 @@ sub new {
     my ( $iClass, $iBBS ) = @_;
     my $iConfig = $iBBS->get_kernel()->get_config();
 
-    bless [ ( $iConfig->get_int('nicovideo.width') || 320 ),
-            ( $iConfig->get_int('nicovideo.height') || 216 ),
+    bless [
+        ( $iConfig->get_int('nicovideo.width')  || 320 ),
+        ( $iConfig->get_int('nicovideo.height') || 216 ),
+        ( $iConfig->get('EnableXHTMLBreak') ? '<br />' : '<br>' ),
     ], $iClass;
 }
 
 sub from_bbs {
     my ( $iObject, $key, $count, $resno, $text ) = @_;
-    my ( $width, $height ) = ( $iObject->[0], $iObject->[1] );
+    my ( $width, $height, $break )
+        = ( $iObject->[0], $iObject->[1], $iObject->[2] );
 
     $$text =~ s{
         (?:\<a[^>]+>)?
-        http://w?w?w?\.?nicovideo\.jp/watch\?v=(\w+)
+        http://w?w?w?\.?nicovideo\.jp/watch/?(?:\?v=)?(\w+)
         (?:\</a>)?
         }
         {<iframe src="http://www.nicovideo.jp/thumb?v=$1"
   width="${width}" height="${height}" frameborder="0" scrolling="no">
-</iframe><br />}gxms;
+</iframe>${break}}gxms;
     return;
 }
 
