@@ -14,26 +14,24 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Note.pm 256 2007-02-17 14:37:05Z hikarin $
+# $Id: Note.pm 1230 2007-10-01 13:40:05Z hikarin $
 #
 
 package Img0ch::Plugin::Upload::Note;
 
 use strict;
+use Img0ch::Plugin::Module::Draft qw();
+use Img0ch::Plugin::Module::Note qw();
 
 sub new {
     my ( $iClass, $iBBS, $key, $called ) = @_;
     $called eq 'iterator' or return;
 
-    require Img0ch::Plugin::Module::Note;
-    require Img0ch::Upload;
     my $iConfig  = $iBBS->get_kernel()->get_config();
     my $iNote    = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
-    my $iSetting = Img0ch::Setting->new($iBBS);
-    my $iUpload  = Img0ch::Upload->new( $iBBS, $key );
-    my $cgi      = ( $iConfig->get('CGIServer')
-        || join( '/', $iConfig->get('Server'), 'test' ) )
-        . '/img0ch-note.cgi';
+    my $iSetting = $iBBS->get_setting_instance();
+    my $iUpload  = $iBBS->get_upload_instance($key);
+    my $cgi = Img0ch::Request->get_app_uri2($iConfig) . '/img0ch-note.cgi';
 
     bless {
         __bbs       => $iBBS->get_name(),
@@ -45,55 +43,59 @@ sub new {
 }
 
 sub save {
-    my ($iApp)  = @_;
+    my ($iApp) = @_;
     my $iRequest = $iApp->request();
 
     if ( ( ref $iRequest || '' ) eq 'Img0ch::App::Note::Request' ) {
         my $iUpload = $iApp->upload();
-        my $path = $iUpload->get_uploaded_file_path();
+        my $path    = $iUpload->get_uploaded_file_path();
         my ( $resno, $ext ) = $path =~ m{/(\d+)\.(\w+)\z}xms or return 1;
 
-        require Img0ch::Plugin::Module::Note;
         my $iBBS  = $iApp->bbs();
         my $key   = $iRequest->key();
         my $pass  = $iRequest->param('editpass');
         my $iNote = Img0ch::Plugin::Module::Note->new( $iBBS, $key );
         if ( my $id = $iRequest->param_int('noteID') ) {
-            require Img0ch::Plugin::Module::Draft;
             my $iDraft = $iApp->get_draft_repository()
-                || Img0ch::Plugin::Module::Draft->new($iApp->kernel());
+                || Img0ch::Plugin::Module::Draft->new( $iApp->kernel() );
             my $modified = $iDraft->get_last_modified($id);
             if ($modified) {
                 $pass ||= $iDraft->get_edit_pass();
-                $iNote->set($resno, {
-                    animation => \$iDraft->get_animation($id),
-                    applet => $iApp->get_applet_type(),
-                    ellapse => $iDraft->get_ellapse($id),
-                    modified => $modified,
-                    pass => $pass,
-                    type => $iDraft->get_image_type($id) });
+                $iNote->set(
+                    $resno,
+                    {   animation => \$iDraft->get_animation($id),
+                        applet    => $iApp->get_applet_type(),
+                        ellapse   => $iDraft->get_ellapse($id),
+                        modified  => $modified,
+                        pass      => $pass,
+                        type      => $iDraft->get_image_type($id)
+                    }
+                );
                 $iNote->save();
             }
         }
         else {
             my $pass = $iRequest->param('editpass');
-            $iNote->set($resno, {
-                animation => $iRequest->get_animation(),
-                applet => $iApp->get_applet_type(),
-                ellapse => $iRequest->param_int('timer'),
-                modified => $iRequest->now(),
-                pass => $pass,
-                type => $ext });
+            $iNote->set(
+                $resno,
+                {   animation => $iRequest->get_animation(),
+                    applet    => $iApp->get_applet_type(),
+                    ellapse   => $iRequest->param_int('timer'),
+                    modified  => $iRequest->now(),
+                    pass      => $pass,
+                    type      => $ext
+                }
+            );
             $iNote->save();
         }
     }
     return 1;
 }
 
-my $animation = pack 'C*', 0x83, 0x41, 0x83, 0x6a, 0x83,
-    0x81, 0x81, 0x5b, 0x83, 0x56, 0x83, 0x87, 0x83, 0x93;
-my $continue = pack 'C*', 0x91, 0xb1, 0x82,
-    0xab, 0x82, 0xf0, 0x95, 0x60, 0x82, 0xad;
+my $animation = pack 'C*', 0x83, 0x41, 0x83, 0x6a, 0x83, 0x81, 0x81, 0x5b,
+    0x83, 0x56, 0x83, 0x87, 0x83, 0x93;
+my $continue = pack 'C*', 0x91, 0xb1, 0x82, 0xab, 0x82, 0xf0, 0x95, 0x60,
+    0x82, 0xad;
 
 sub rewrite {
     my ( $iObject, $key, $count, $resno, $text ) = @_;
@@ -103,8 +105,8 @@ sub rewrite {
         $iNote->set_key($key);
         $iUpload->set_key($key);
         $iObject->{__cache_key} = $key;
-        $iObject->{__note} = $iNote;
-        $iObject->{__upload} = $iUpload;
+        $iObject->{__note}      = $iNote;
+        $iObject->{__upload}    = $iUpload;
     }
 
     my $hash = $iNote->get($resno);
@@ -113,14 +115,13 @@ sub rewrite {
     my $bbs = $iObject->{__bbs};
     my $cgi = $iObject->{__cgi};
 
-    $$text .= join '', '<br /><br /><a href="', $cgi,
-        '/continue/', $bbs, '/', $key, '/', $resno,
-        '?width=', $width, '&height=', $height, '"><b>[',
+    $$text .= join '', '<br /><br /><a href="', $cgi, '/continue/', $bbs, '/',
+        $key, '/', $resno, '?width=', $width, '&height=', $height, '"><b>[',
         $continue, ']</b></a>';
-    if ($hash->{animation}) {
-        $$text .= join '', ' <a href="', $cgi, '/animate/',
-            $bbs, '/', $key, '/', $resno, '?width=', $width,
-            '&height=', $height, '"><b>[', $animation, ']</b></a>';
+    if ( $hash->{animation} ) {
+        $$text .= join '', ' <a href="', $cgi, '/animate/', $bbs, '/', $key,
+            '/', $resno, '?width=', $width, '&height=', $height, '"><b>[',
+            $animation, ']</b></a>';
     }
     return;
 }
