@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Subject.pm 904 2007-07-18 13:31:12Z hikarin $
+# $Id: Subject.pm 1405 2007-10-16 13:36:28Z hikarin $
 #
 
 package Img0ch::Subject;
@@ -42,17 +42,15 @@ sub load {
     my $order   = [];
 
     $path ||= $iSubject->path();
-    -r $path or return 0;
-    local ( $!, *FH );
+    my $fh = $iKernel->get_read_file_handle($path) || return 0;
 
-    open *FH, "<${path}" or $iKernel->throw_io_exception($path);  ## no critic
-    while ( my $line = <FH> ) {
+    while ( my $line = <$fh> ) {
         $line =~ /\A(\d+)\.dat<>(.+?)\s?\((\d+)\)\n\z/xms or next;
         my ( $key, $subject, $res ) = ( $1, $2, $3 );
         $buffer->{$key} = [ $subject, $res ];
         push @{$order}, $key;
     }
-    close *FH or $iKernel->throw_io_exception($path);
+    close $fh or $iKernel->throw_io_exception($path);
 
     %{ $iSubject->{_cache} } = %{$buffer};
     my $count = @{ $iSubject->{_order} } = @{$order};
@@ -65,25 +63,17 @@ sub save {
     my $iKernel = $iSubject->{_kernel};
 
     $path ||= $iSubject->{__path};
-    my $temp    = $path . '.tmp';
-    my $LOCK_EX = 2;
-    eval {
-        require Fcntl;
-        $LOCK_EX = Fcntl::LOCK_EX();
-    };
+    my $temp = $path . '.tmp';
 
     eval {
-        local ( $!, *FH );
-        open *FH, ">${temp}"    ## no critic
-            or $iKernel->throw_io_exception($path);
-        flock *FH, $LOCK_EX;
+        my $fh   = $iKernel->get_write_file_handle($temp);
         my $keys = $iSubject->to_array();
         for my $key (@$keys) {
             my $rs = $iSubject->get($key);
-            print {*FH} $key, '.dat<>', $rs->[0], ' (', $rs->[1], ')', "\n"
+            print ${fh} $key, '.dat<>', $rs->[0], ' (', $rs->[1], ')', "\n"
                 or $iKernel->throw_io_exception($path);
         }
-        close *FH or $iKernel->throw_io_exception($path);
+        close $fh or $iKernel->throw_io_exception($path);
         rename $temp, $path or $iKernel->throw_io_exception($path);
     };
     if ( my $exception = $@ ) {
@@ -123,7 +113,17 @@ sub sage {
 *raise = \&age;
 
 sub age {
-    my ( $iSubject, $key, $res, $subject ) = @_;
+    _shift( sub { unshift @{ $_[0] }, $_[1] }, @_ );
+}
+
+*drop = \&dame;
+
+sub dame {
+    _shift( sub { push @{ $_[0] }, $_[1] }, @_ );
+}
+
+sub _shift {
+    my ( $subref, $iSubject, $key, $res, $subject ) = @_;
     my $order = $iSubject->{_order};
 
     for ( my $i = 0; $i < @{$order}; $i++ ) {
@@ -133,23 +133,33 @@ sub age {
         }
     }
 
-    unshift @{$order}, $key;
+    $subref->( $order, $key );
     my $old = $iSubject->get($key);
     $iSubject->{_cache}->{$key} = [ ( $old->[0] || $subject ), $res ];
     1;
 }
 
 sub search {
-    my ( $iSubject, $regex ) = @_;
-    require ShiftJIS::Regexp;
-    my $re  = ShiftJIS::Regexp::re($regex);
+    my ( $iThread, $word ) = @_;
+    defined $ShiftJIS::Regexp::VERSION or require ShiftJIS::Regexp;
+    return $iThread->_search( ShiftJIS::Regexp::re($word) );
+}
+
+sub grep {
+    my ( $iThread, $word ) = @_;
+    return $iThread->_search(qr/\Q$word\E/xms);
+}
+
+sub _search {
+    my ( $iSubject, $re ) = @_;
     my $ret = {};
 
     for my $key ( @{ $iSubject->to_array() } ) {
         my $rs = $iSubject->get($key);
-        $rs->[0] =~ /$re/xms and $ret->{$key} = $rs;
+        $rs->[0] =~ $re and $ret->{$key} = $rs;
     }
-    $ret;
+
+    return $ret;
 }
 
 sub to_array { $_[0]->{_order} }
