@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Upload.pm 970 2007-08-21 14:52:15Z hikarin $
+# $Id: Upload.pm 1250 2007-10-02 14:14:25Z hikarin $
 #
 
 package Img0ch::Upload;
@@ -52,7 +52,7 @@ sub new {
         _kernel  => $iKernel,
         _key     => $key,
         _path    => $iBBS->path( 'img', $key ),
-        __prefix => "I:U:I.${bbs}.${key}",
+        _prefix  => "I:U:I.${bbs}.${key}",
         __rmpass => '',
         _rs      => $iReposUpload,
         _tag     => $iReposTag,
@@ -82,7 +82,6 @@ sub save {
     my $iKernel = $iUpload->{_kernel};
     my $dir     = $iUpload->path();
     if ( !-d $dir ) {
-        local $!;
         mkdir $dir, 0755 or $iKernel->throw_io_exception($dir);
     }
 
@@ -91,22 +90,21 @@ sub save {
     my $path = $iUpload->path( $resno, $ext );
     my $file_not_uploaded = -r $path ? 0 : 1;
 
-    require File::Copy;
-    local $!;
+    defined $File::Copy::VERSION or require File::Copy;
     if ( !File::Copy::copy( $src, $path ) ) {
         my $file = !-e $src ? $src : $path;
         $iKernel->throw_io_exception($file);
     }
 
     my ( $width, $height ) = $iUpload->get_dimensions($src);
-    my $prefix = "I:U:I.${bbs}.${key}.${resno}";
+    my $prefix = join '.', $iUpload->{_prefix}, $resno;
     $iReposUpload->set( "${prefix}.extension", $ext );
     $iReposUpload->set( "${prefix}.width",     $width );
     $iReposUpload->set( "${prefix}.height",    $height );
     $iReposUpload->set( "${prefix}.hash",      $iUpload->get_digest($src) );
     $file_not_uploaded
-        and
-        $iReposUpload->set( "I:U:I.${bbs}.${key}._", ++$iUpload->{_count} );
+        and $iReposUpload->set( join( '.', $iUpload->{_prefix}, '_' ),
+        ++$iUpload->{_count} );
 
     if ( my $dlkey = $iUpload->{__dlpass} ) {
         chmod 0600, $path;
@@ -135,29 +133,22 @@ sub update_csv {
     my $iKernel = $iUpload->{_kernel};
     my $path    = $iUpload->path() . '/upload.csv';
     my $temp    = $path . '.tmp';
-    my $LOCK_EX = 2;
 
     eval {
-        require Fcntl;
-        $LOCK_EX = Fcntl::LOCK_EX();
-    };
-    eval {
-        local ( $!, *FH );
-        open *FH, ">${temp}"    ## no critic
-            or $iKernel->throw_io_exception($path);
-        flock *FH, $LOCK_EX;
+        my $fh    = $iKernel->get_write_file_handle($temp);
         my $count = 0;
         for ( my $i = 0; $i <= $max; $i++ ) {
+            $iUpload->is_freezed($i) and next;
             my $info = $iUpload->get($i);
             if ( my $ext = $info->[0] ) {
                 my ( $w, $h ) = ( 0, 0 );
                 $iUpload->get_thumbnail_size( $i, \$w, \$h );
-                print {*FH} $i, ',', $ext, ',', $info->[1], ',', $info->[2],
+                print ${fh} $i, ',', $ext, ',', $info->[1], ',', $info->[2],
                     ',', $info->[3], ',', $w, ',', $h, "\n"
                     or $iKernel->throw_io_exception($path);
             }
         }
-        close *FH or $iKernel->throw_io_exception($path);
+        close $fh or $iKernel->throw_io_exception($path);
         rename $temp, $path or $iKernel->throw_io_exception($path);
     };
     if ( my $exception = $@ ) {
@@ -172,7 +163,7 @@ sub update_csv {
 
 sub get {
     my ( $iUpload, $resno ) = @_;
-    my $prefix = join '.', $iUpload->{__prefix}, $resno;
+    my $prefix = join '.', $iUpload->{_prefix}, $resno;
     my $iReposUpload = $iUpload->{_rs};
 
     if ( my $hash = $iReposUpload->get("${prefix}.hash") ) {
@@ -188,7 +179,7 @@ sub get {
 
 sub get_thumbnail_size {
     my ( $iUpload, $resno, $ref_width, $ref_height ) = @_;
-    my $prefix = join '.', $iUpload->{__prefix}, $resno;
+    my $prefix = join '.', $iUpload->{_prefix}, $resno;
     my $iReposUpload = $iUpload->{_rs};
 
     if ( my $width = $iReposUpload->get_int("${prefix}.width.thumbnail") ) {
@@ -208,31 +199,20 @@ sub set {
 
 sub set_key {
     my ( $iUpload, $key ) = @_;
-    my $iBBS    = $iUpload->{_i0_bbs};
-    my $iKernel = $iUpload->{_kernel};
-    my $bbs     = $iUpload->{_dir};
-    $iUpload->{_key} = $key;
-
-    my ( undef, undef, undef, $day, $month, $year ) = localtime($key);
-    $year  += 1900;
-    $month += 1;
+    my $iBBS = $iUpload->{_i0_bbs};
+    my $bbs  = $iUpload->{_dir};
     my $repos_upload
-        = $iBBS->get_repos_path( $year, $month, $day, $key, 'upload' );
-    my $repos_upload_dir = $repos_upload;
-    $repos_upload_dir =~ s{/upload.\w+\z}{}xms;
-    if ( !-d $repos_upload_dir ) {
-        require File::Path;
-        File::Path::mkpath($repos_upload_dir)
-            or $iKernel->throw_io_exception($repos_upload_dir);
-    }
+        = Img0ch::Maple::create_repository_subdirs( $key, 'upload', $iBBS );
 
-    my $prefix       = "I:U:I.${bbs}.${key}";
-    my $iReposUpload = $iKernel->get_repos($repos_upload);
-    $iUpload->{_count}   = $iReposUpload->get_int("${prefix}._");
-    $iUpload->{_path}    = $iBBS->path( 'img', $key );
-    $iUpload->{_rs}      = $iReposUpload;
-    $iUpload->{_url}     = $iBBS->url( 'img', $key );
-    $iUpload->{__prefix} = $prefix;
+    my $prefix = join '.', 'I:U:I', $iUpload->{_dir}, $key;
+    my $iReposUpload = $iUpload->{_kernel}->get_repos($repos_upload);
+
+    $iUpload->{_count}  = $iReposUpload->get_int("${prefix}._");
+    $iUpload->{_key}    = $key;
+    $iUpload->{_path}   = $iBBS->path( 'img', $key );
+    $iUpload->{_rs}     = $iReposUpload;
+    $iUpload->{_url}    = $iBBS->url( 'img', $key );
+    $iUpload->{_prefix} = $prefix;
     return;
 }
 
@@ -243,14 +223,14 @@ sub set_remove_password { $_[0]->{__rmpass} = $_[1]; return; }
 sub have_download_password {
     my ( $iUpload, $resno ) = @_;
     my $iReposUpload = $iUpload->{_rs};
-    return $iReposUpload->get( join '.', $iUpload->{__prefix}, $resno,
+    return $iReposUpload->get( join '.', $iUpload->{_prefix}, $resno,
         'download.pass' ) ? 1 : 0;
 }
 
 sub set_thumbnail_size {
     my ( $iUpload, $resno, $width, $height ) = @_;
     my $iReposUpload = $iUpload->{_rs};
-    my $prefix = join '.', $iUpload->{__prefix}, $resno;
+    my $prefix = join '.', $iUpload->{_prefix}, $resno;
     $iReposUpload->set( "${prefix}.width.thumbnail",  $width );
     $iReposUpload->set( "${prefix}.height.thumbnail", $height );
     return;
@@ -278,12 +258,14 @@ sub can_remove { shift->_can( 'remove', @_ ) }
 
 sub _can {
     my ( $iUpload, $type, $resno, $pass ) = @_;
-    my $key_by_type = join '.', $iUpload->{__prefix}, $resno, $type, 'pass';
-    my $iReposUpload = $iUpload->{_rs};
+    $iUpload->is_freezed($resno) and return 0;
 
+    my $key_by_type = join '.', $iUpload->{_prefix}, $resno, $type, 'pass';
+    my $iReposUpload = $iUpload->{_rs};
     if ( my $pass_md5 = $iReposUpload->get($key_by_type) ) {
         return Digest::MD5::md5_base64($pass) eq $pass_md5;
     }
+
     return 0;
 }
 
@@ -299,17 +281,19 @@ sub _get_digest {
 
     -r $path or return '';
     -z $path and return '';
-    local ( $!, *FH );
 
-    open *FH, "<${path}" or $iKernel->throw_io_exception($path);  ## no critic
-    binmode *FH;
+    my $fh = $iKernel->get_read_file_handle($path);
+    binmode $fh;
+
     my $md5 = Digest::MD5->new();
-    while ( read *FH, my $buffer, 32768 ) {
+    while ( read $fh, my $buffer, 32768 ) {
         $md5->add($buffer);
     }
+
     my $digest = $md5->$md5_method();
-    close *FH or $iKernel->throw_io_exception($path);
-    $digest;
+    close $fh or $iKernel->throw_io_exception($path);
+
+    return $digest;
 }
 
 sub get_dimensions {
@@ -317,7 +301,7 @@ sub get_dimensions {
     my ( $width, $height ) = ( 0, 0 );
 
     if ($path =~ /\.jpg\z/xms
-        and ( defined $INC{'Image/Epeg.pm'}
+        and ( defined $Image::Epeg::VERSION
             or eval 'use Image::Epeg qw(); 1' )
         )
     {
@@ -327,16 +311,13 @@ sub get_dimensions {
             $height = $epeg->get_height();
         }
     }
-
-    #    elsif ($path !~ /\.gif$/ and eval 'use Image::Imlib2 qw(); 1') {
-    #        my $imlib = Image::Imlib2->new;
-    #        $imlib->load($path);
-    #        if ($imlib) {
-    #            $width = $imlib->get_width;
-    #            $height = $imlib->get_height;
-    #        }
-    #    }
-    elsif ( defined $INC{'GD.pm'} or eval 'use GD qw(); 1' ) {
+    elsif ( defined $Imager::VERSION or eval 'use Imager qw(); 1' ) {
+        my $image = Imager->new();
+        $image->read( file => $path );
+        $width  = $image->getwidth();
+        $height = $image->getheight();
+    }
+    elsif ( defined $GD::VERSION or eval 'use GD qw(); 1' ) {
         my $gd = sub {
             return GD::Image->newFromJpeg($path) if $path =~ /\.jpg\z/xms;
             return GD::Image->newFromPng($path)  if $path =~ /\.png\z/xms;
@@ -350,7 +331,7 @@ sub get_dimensions {
             ( $width, $height ) = $gd->getBounds();
         }
     }
-    elsif ( defined $INC{'Image/Magick.pm'}
+    elsif ( defined $Image::Magick::VERSION
         or eval 'use Image::Magick qw(); 1' )
     {
         my $image = Image::Magick->new;
@@ -368,6 +349,15 @@ sub get_dimensions {
     ( $width, $height );
 }
 
+sub is_removed {
+    my ( $iUpload, $hash ) = @_;
+    $hash ||= $iUpload->get_digest( $iUpload->{__upload}->[0] );
+
+    require Img0ch::Upload::Removed;
+    my $iURemoved = Img0ch::Upload::Removed->new( $iUpload->{_i0_bbs} );
+    return $iURemoved->is_removed($hash) ? 1 : 0;
+}
+
 sub get_uploaded_file_path { $_[0]->{__path} }
 
 sub get_uploaded_file_url { $_[0]->{__url} }
@@ -484,24 +474,69 @@ sub scale {
     ( $width, $height );
 }
 
+sub freeze { _freeze_or_release( [ 0600, 0700 ], 1, @_ ) }
+
+sub release { _freeze_or_release( [ 0644, 0755 ], 0, @_ ) }
+
+sub _freeze_or_release {
+    my ( $permission, $is_freeze, $iUpload, $resno ) = @_;
+    my ( $iRepos, $extension, $prefix );
+
+    $resno = Img0ch::Kernel::intval($resno);
+    if ($resno) {
+        $prefix    = join '.', $iUpload->{_prefix}, $resno;
+        $iRepos    = $iUpload->{_rs};
+        $extension = $iRepos->get("${prefix}.extension") || return 0;
+    }
+
+    my $path = $iUpload->path( $resno, $extension );
+    if ( -e $path ) {
+        -f $path and chmod $permission->[0], $path;
+        -d $path and chmod $permission->[1], $path;
+        if ($iRepos) {
+            my $thumbnail = $iUpload->path( "t${resno}", $extension );
+            -f $thumbnail and chmod $permission->[0], $thumbnail;
+            $iRepos->set( "${prefix}.protected", $is_freeze );
+            $iRepos->save();
+        }
+        return 1;
+    }
+    return 0;
+}
+
+sub is_freezed {
+    my ( $iUpload, $resno ) = @_;
+    if ($resno) {
+        my $prefix = join '.', $iUpload->{_prefix}, $resno;
+        return $iUpload->{_rs}->get("${prefix}.protected") ? 1 : 0;
+    }
+    else {
+        my $path = $iUpload->path();
+        if ( -e $path ) {
+            my $permission = ( stat($path) )[2] & 07777;
+            return ( $permission == 0600 or $permission == 0700 ) ? 1 : 0;
+        }
+        return 0;
+    }
+}
+
 sub traverse {
     my ($iUpload) = @_;
     my $iKernel   = $iUpload->{_kernel};
     my $path      = $iUpload->path();
     -d $path or return 0;
 
-    local ( $!, *DH );
-    opendir *DH, $path or $iKernel->throw_io_exception($path);
-    my @file_list = readdir *DH;
-    require File::Spec;
+    defined $File::Spec::VERSION or require File::Spec;
+    opendir my $fh, $path or $iKernel->throw_io_exception($path);
+    my @file_list = readdir $fh;
     @file_list = File::Spec->no_upwards(@file_list);
-    closedir *DH or $iKernel->throw_io_exception($path);
+    closedir $fh or $iKernel->throw_io_exception($path);
 
     return [ map { File::Spec->catfile( $path, $_ ) } @file_list ];
 }
 
 sub remove {
-    my ( $iUpload, $resno_or_path ) = @_;
+    my ( $iUpload, $resno_or_path, $save_removed_hash ) = @_;
     my $iReposUpload = $iUpload->{_rs};
 
     my $resno;
@@ -512,7 +547,7 @@ sub remove {
         -r $resno_or_path or return 0;
         ($resno) = $resno_or_path =~ m{/t?(\d+)\.[\w\.]+\z}xms;
     }
-    my $prefix_top = $iUpload->{__prefix};
+    my $prefix_top = $iUpload->{_prefix};
     my $prefix     = join '.', $prefix_top, $resno;
     my $extension  = $iReposUpload->get("${prefix}.extension");
 
@@ -520,6 +555,15 @@ sub remove {
     if ( ( -f $uploaded_file_path or -l $uploaded_file_path )
         and -w $uploaded_file_path )
     {
+        if ($save_removed_hash) {
+            require Img0ch::Upload::Removed;
+            my $iBBS      = $iUpload->{_i0_bbs};
+            my $key       = $iUpload->{_key};
+            my $iURemoved = Img0ch::Upload::Removed->new($iBBS);
+            $iURemoved->set( $iUpload->get_digest($uploaded_file_path),
+                $key, $resno );
+            $iURemoved->save();
+        }
         my $iKernel = $iUpload->{_kernel};
         unlink $uploaded_file_path
             or $iKernel->throw_io_exception($uploaded_file_path);
@@ -530,7 +574,7 @@ sub remove {
         unlink $thumbnail or $iKernel->throw_io_exception($thumbnail);
     }
 
-    $iReposUpload->remove("${prefix}.remove");
+    $iReposUpload->remove("${prefix}.remove.pass");
     $iReposUpload->remove("${prefix}.extension");
     $iReposUpload->remove("${prefix}.width");
     $iReposUpload->remove("${prefix}.height");
@@ -616,6 +660,23 @@ none
 I<set()>で指定された場所にファイルをアップロードし、保存します。
 I<set()>が一度も呼び出されていなければ0を返します。
 
+=head2 update_csv
+
+=over 4
+
+=item Arguments
+
+$count_of_reses
+
+=item Return Value
+
+1(saved) or 0
+
+=back
+
+現在のファイルデータベースからCSVを生成します。
+何もアップロードされていない場合を除いて1を返します。
+
 =head2 get
 
 =over 4
@@ -872,6 +933,23 @@ Image::Infoはpureperlの画像情報処理ライブラリです。
 
 =back
 
+=head2 is_removed
+
+=over 4
+
+=item Arguments
+
+$hash_of_uploaded_file
+
+=item Return Value
+
+1 or 0
+
+=back
+
+ファイルのハッシュから過去に削除されたファイルのハッシュであるかどうかをテストします。
+一致したならば1を、そうでない場合は0を返します。
+
 =head2 get_tags
 
 =over 4
@@ -907,6 +985,22 @@ $array_reference_of_found
 全てのタグの数を調べます。それぞれタグ名、タグの発見数の順番で
 構成された配列のリファレンスのリファレンスを返します。
 
+=head2 get_tag_count_utf8
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$array_reference_of_found
+
+=back
+
+タグ名がそれぞれutf8で返される点以外はI<get_tag_count()>と同様です。
+
 =head2 set_tags
 
 =over 4
@@ -941,6 +1035,61 @@ $width, $height, $max_width, $max_height
 
 $max_widthと$max_heightから画像の大きさを縮小した結果を返します。
 
+=head2 freeze
+
+=over 4
+
+=item Arguments
+
+$resno?
+
+=item Return Value
+
+1 or 0(none)
+
+=back
+
+ファイルの凍結を行います。凍結されたファイルは削除及びダウンロードが不可能になります。
+凍結を解除するにはI<release()>を利用してください。
+引数が無い場合はオブジェクト内部のスレッドキーのディレクトリ全体に凍結を行います。
+成功した場合は1を、失敗した場合(ファイルが存在しないまたはデータに登録されていない)は0を返します。
+
+=head2 release
+
+=over 4
+
+=item Arguments
+
+$resno?
+
+=item Return Value
+
+1 or 0(none)
+
+=back
+
+ファイルの凍結の凍結解除を行います。
+引数が無い場合はオブジェクト内部のスレッドキーのディレクトリ全体に凍結解除を行います。
+成功した場合は1を、失敗した場合(ファイルが存在しないまたはデータに登録されていない)は0を返します。
+
+=head2 is_freezed
+
+=over 4
+
+=item Arguments
+
+$resno?
+
+=item Return Value
+
+1 or 0
+
+=back
+
+ファイルの凍結が行われているかをテストします。
+引数が無い場合はオブジェクト内部のスレッドキーのディレクトリ全体をテストします。
+凍結状態にある場合は1、そうで無い場合は0を返します。
+
 =head2 traverse
 
 =over 4
