@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 900 2007-07-14 14:27:12Z hikarin $
+# $Id: BBS.pm 1437 2007-10-19 13:29:13Z hikarin $
 #
 
 package Zeromin::BBS;
@@ -25,9 +25,11 @@ use base qw(Img0ch::BBS);
 sub new {
     my ( $zClass, $iKernel, $hash ) = @_;
     my $zBBS = $zClass->SUPER::new( $iKernel, $hash );
-    my $dir = $hash->{bbs} || $zBBS->{_dir};
-    $zBBS->{_dir} = $dir;
-    $zBBS->{_path} = join '/', $iKernel->get_config()->get('BBSPath'), $dir;
+    my $base = $iKernel->get_config()->get('BBSPath');
+    my $dir  = $hash->{bbs} || $zBBS->{_dir};
+    $zBBS->{_base} = $base;
+    $zBBS->{_dir}  = $dir;
+    $zBBS->{_path} = join '/', $base, $dir;
     $zBBS;
 }
 
@@ -110,31 +112,28 @@ sub create {
     require Zeromin::Metadata;
     my $zMeta = Zeromin::Metadata->new($zBBS);
     {
-        local ( $!, *FH );
-
+        my $fh;
         my $head = join '/', $init, 'default_hed.txt';
-        open *FH, "<${head}"    ## no critic
-            or $iKernel->throw_io_exception($head);
+
+        $fh = $iKernel->get_read_file_handle($head);
         $zMeta->head(
-            \do { local $/ = undef; <FH> }
+            \do { local $/ = undef; <$fh> }
         );
-        close *FH or $iKernel->throw_io_exception($head);
+        close $fh or $iKernel->throw_io_exception($head);
 
         my $meta = join '/', $init, 'default_fot.txt';
-        open *FH, "<${meta}"    ## no critic
-            or $iKernel->throw_io_exception($meta);
+        $fh = $iKernel->get_read_file_handle($meta);
         $zMeta->foot(
-            \do { local $/ = undef; <FH> }
+            \do { local $/ = undef; <$fh> }
         );
-        close *FH or $iKernel->throw_io_exception($meta);
+        close $fh or $iKernel->throw_io_exception($meta);
 
         my $t_end = join '/', $static, '1000.txt';
-        open *FH, "<${t_end}"    ## no critic
-            or $iKernel->throw_io_exception($t_end);
+        $fh = $iKernel->get_read_file_handle($t_end);
         $zMeta->thread_end(
-            \do { local $/ = undef; <FH> }
+            \do { local $/ = undef; <$fh> }
         );
-        close *FH or $iKernel->throw_io_exception($t_end);
+        close $fh or $iKernel->throw_io_exception($t_end);
     }
 
     require Zeromin::Setting;
@@ -142,24 +141,26 @@ sub create {
     for my $key ( @{ $zSetting->keyset(1) } ) {
         $zSetting->set( $key, $zSetting->get_default($key) );
     }
+
+    $zSetting->set( 'BBS_BG_PICTURE',      "../${bbs}/ba.gif" );
+    $zSetting->set( 'BBS_TITLE_PICTURE',   "../${bbs}/kanban.gif" );
+    $zSetting->set( 'BBS_REFERER_CUSHION', 'ime.nu/' );
+
     if ( my $inherit = $hash->{inherit} ) {
-        my $zBBSInherit     = Img0ch::BBS->new($inherit);
-        my $zSettingInherit = Zeromin::Setting->new($zBBSInherit);
-        $zSetting->merge($zSettingInherit);
-    }
-    else {
-        $zSetting->set( 'BBS_BG_PICTURE',      "../${bbs}/ba.gif" );
-        $zSetting->set( 'BBS_TITLE_PICTURE',   "../${bbs}/kanban.gif" );
-        $zSetting->set( 'BBS_REFERER_CUSHION', 'ime.nu/' );
+        my $iBBSInherit = Img0ch::BBS->new( $iKernel, { id => $inherit } );
+        $iBBSInherit->get_id()
+            or $iBBSInherit
+            = Img0ch::BBS->new( $iKernel, { bbs => $inherit } );
+        $zSetting->merge( Zeromin::Setting->new($iBBSInherit) );
     }
+
     $zSetting->set( 'BBS_TITLE',    $hash->{title} );
     $zSetting->set( 'BBS_SUBTITLE', $hash->{sub_title} );
     $zSetting->set( 'BBS_READONLY', 'on' );
     $zSetting->set( 'BBS_MODE', $hash->{uploadable} ? 'picture' : 'none' );
     $zSetting->save();
 
-    require Img0ch::Subject;
-    my $iSubject = Img0ch::Subject->new($zBBS);
+    my $iSubject = $zBBS->get_subject_instance();
     $iSubject->save("${path}/subject.txt");
     $iRepos->save();
 
@@ -199,6 +200,16 @@ sub remove {
     my $zUser    = Zeromin::User->new($iBBS);
     $zPlugin->do( 'zeromin.remove.bbs', $iBBS );
 
+    $zCap->remove_from_bbs();
+    $zPlugin->remove_from_bbs();
+    $zUser->remove_from_bbs();
+    $zSetting->remove();
+
+    for my $object ( $zFIP, $zFNG ) {
+        map { $object->remove( $_->{id} ) } @{ $object->all_in() };
+        $object->save();
+    }
+
     my $bbs = $zBBS->get_name();
     my $id  = $zBBS->get_id();
     $iRepos->remove("I:B.c.${id}");
@@ -206,39 +217,15 @@ sub remove {
     $iRepos->remove("I:B.i.${id}");
     $iRepos->save();
 
-    -d $path or return 1;
-    $zCap->remove_from_bbs();
-    $zPlugin->remove_from_bbs();
-    $zUser->remove_from_bbs();
-    $zMeta->remove();
-    $zSetting->remove();
-    for my $object ( $zFIP, $zFNG ) {
-        map { $object->remove( $_->{id} ) } @{ $object->all_in() };
-        $object->save();
-    }
+    defined $File::Basename::VERSION or require File::Basename;
+    my $repos  = File::Basename::dirname( $zBBS->get_repos_path('a') );
+    my @remove = ($repos);
+    !$only_db_data and push @remove, $path;
 
-    require File::Basename;
-    my $repos_path = File::Basename::dirname( $zBBS->get_repos_path('a') );
-    require File::Find;
-    File::Find::find(
-        {   bydepth  => 1,
-            no_chdir => 1,
-            untaint  => 1,
-            wanted   => sub {
-                if ( !-l and -d _ ) {
-                    rmdir $File::Find::name
-                        or $iKernel->throw_io_exception($File::Find::name);
-                }
-                else {
-                    unlink $File::Find::name
-                        or $iKernel->throw_io_exception($File::Find::name);
-                }
-                }
-        },
-        $path,
-        $repos_path,
-    );
-    1;
+    defined $File::Path::VERSION or require File::Path;
+    File::Path::rmtree( \@remove );
+
+    return 1;
 }
 
 sub rebuild {
@@ -298,11 +285,9 @@ sub update_bbsmenu {
             };
     }
 
-    require Unicode::Japanese;
     require Zeromin::Category;
     my $iKernel   = $zBBS->get_kernel();
     my $zCategory = Zeromin::Category->new($iKernel);
-    my $unijp     = Unicode::Japanese->new();
     my $encoding  = $iKernel->get_encoding(1);
     my $tagset    = [];
     for my $cat_id ( sort keys %$category ) {
@@ -311,8 +296,10 @@ sub update_bbsmenu {
             {
             boards => $category->{$cat_id},
             id     => $cat_id,
-            name   => $unijp->set( $zCategory->get($cat_id)->{name}, 'utf8' )
-                ->$encoding,
+            name   => $iKernel->get_encoded_str(
+                $zCategory->get($cat_id)->{name},
+                $encoding, 'utf8'
+            ),
             };
     }
 
@@ -347,36 +334,41 @@ sub repair_bbs_table {
     my $last_id  = $iRepos->get('I:B._');
     my $repaired = [];
 
-    local ( $!, *DH );
-    opendir *DH, $base or $iKernel->throw_io_exception($base);
-    my @dirs = readdir *DH;
-    closedir *DH;
+    #    for my $id ( @{ $zBBS->get_all_ids() } ) {
+    #        my $zBBSIter = Zeromin::BBS->new( $iKernel, { id => $id } );
+    #        ( $zBBSIter->get_id() and !-d $zBBSIter->path() )
+    #            and $zBBSIter->remove(1);
+    #    }
+
+    opendir my $fh, $base or $iKernel->throw_io_exception($base);
+    my @dirs = readdir $fh;
+    closedir $fh;
 
     require Zeromin::Metadata;
     require Zeromin::Setting;
-    require Img0ch::Subject;
 
+REPAIR:
     for my $dir (@dirs) {
-        $dir =~ /\A\.+\z/xms and next;
-        $dir =~ /\A\W+\z/xms and next;
-        $dir eq 'test' and next;
+        $dir =~ /\A\.+\z/xms and next REPAIR;
+        $dir =~ /\A\W+\z/xms and next REPAIR;
+        $dir eq 'test' and next REPAIR;
 
         my $path = join '/', $base, $dir;
-        -d $path or next;
+        -d $path or next REPAIR;
         my $setting = join '/', $path, 'SETTING.TXT';
-        -r $setting or next;
+        -r $setting or next REPAIR;
         my $setting_hash = {};
 
-        local ( $!, *FH );
-        open *FH, "<${setting}"    ## no critic
-            or $iKernel->throw_io_exception($setting);
-        while ( my $line = <FH> ) {
+        my $fh = $iKernel->get_read_file_handle($setting);
+
+    SETTING:
+        while ( my $line = <$fh> ) {
             chomp $line;
-            $line =~ /\A(\w+)=(.+)\z/xms or next;
+            $line =~ /\A(\w+)=(.+)\z/xms or next SETTING;
             my ( $key, $value ) = ( $1, $2 );
             $setting_hash->{$key} = $value;
         }
-        close *FH or $iKernel->throw_io_exception($setting);
+        close $fh or $iKernel->throw_io_exception($setting);
 
         my $iBBSNew = Zeromin::BBS->new( $iKernel, { bbs => $dir } );
         my $id = $iBBSNew->get_id();
@@ -387,6 +379,7 @@ sub repair_bbs_table {
             $iBBSNew->{_dir} = $dir;
             $iBBSNew->{_id}  = $id;
             $iRepos->save();
+            $iBBSNew->get_common_repos()->load();
         }
 
         my $repos = join '/', $rps_root, $dir;
@@ -397,27 +390,26 @@ sub repair_bbs_table {
         my $zMeta = Zeromin::Metadata->new($iBBSNew);
         {
             local $/ = undef;
-            local ( $!, *FH );
             my $head = join '/', $path, 'head.txt';
             if ( -r $head ) {
-                open *FH, "<${head}"    ## no critic
-                    or $iKernel->throw_io_exception($head);
-                $zMeta->head( \<FH> );
-                close *FH or $iKernel->throw_io_exception($head);
+                $fh = $iKernel->get_read_file_handle($head);
+                my $buffer = <$fh>;
+                close $fh or $iKernel->throw_io_exception($head);
+                $zMeta->head( \$buffer );
             }
             my $meta = join '/', $path, 'meta.txt';
             if ( -r $meta ) {
-                open *FH, "<${meta}"    ## no critic
-                    or $iKernel->throw_io_exception($meta);
-                $zMeta->meta( \<FH> );
-                close *FH or $iKernel->throw_io_exception($meta);
+                $fh = $iKernel->get_read_file_handle($meta);
+                my $buffer = <$fh>;
+                close $fh or $iKernel->throw_io_exception($meta);
+                $zMeta->meta( \$buffer );
             }
             my $foot = join '/', $path, 'foot.txt';
             if ( -r $foot ) {
-                open *FH, "<${foot}"    ## no critic
-                    or $iKernel->throw_io_exception($foot);
-                $zMeta->foot( \<FH> );
-                close *FH or $iKernel->throw_io_exception($foot);
+                $fh = $iKernel->get_read_file_handle($foot);
+                my $buffer = <$fh>;
+                close $fh or $iKernel->throw_io_exception($foot);
+                $zMeta->foot( \$buffer );
             }
         }
 
@@ -427,6 +419,7 @@ sub repair_bbs_table {
                 $setting_hash->{$key} || $zSetting->get_default($key) );
         }
         $zSetting->save();
+
         push @$repaired, $dir;
     }
 
@@ -436,7 +429,6 @@ sub repair_bbs_table {
 sub repair_tag_table {
     my ($zBBS) = @_;
 
-    require Img0ch::Setting;
     require Zeromin::Subject;
     require Zeromin::Thread;
     require Zeromin::Upload;
@@ -444,7 +436,7 @@ sub repair_tag_table {
     my $zSubject = Zeromin::Subject->new($zBBS);
     my $zThread  = Zeromin::Thread->new( $zBBS, 0 );
     my $zUpload  = Zeromin::Upload->new( $zBBS, 0 );
-    my $max      = Img0ch::Setting->new($iBBS)->get_int('BBS_IMG_TAG_MAX');
+    my $max      = $iBBS->get_setting_instance()->get_int('BBS_IMG_TAG_MAX');
 
     $zSubject->load();
     $zThread->disable_xhtml_break();
@@ -540,10 +532,9 @@ sub get {
     my $iRepos = $zBBS->get_common_repos();
     my $dir    = $iRepos->get("I:B.i.${id}");
 
-    if ($dir) {
-        require Img0ch::Setting;
+    if ( $dir and -d join( '/', $zBBS->{_base}, $dir ) ) {
         my $iBBS     = Img0ch::BBS->new( $zBBS->get_kernel(), { id => $id } );
-        my $iSetting = Img0ch::Setting->new($iBBS);
+        my $iSetting = $iBBS->get_setting_instance();
         my $name     = $iSetting->get('BBS_TITLE');
         my $subname  = $iSetting->get('BBS_SUBTITLE');
         my $category = $iRepos->get("I:B.c.${id}") || 1;
@@ -589,8 +580,27 @@ sub gets_with_page {
 
 sub all {
     my ( $zBBS, $unijp, $zCategory ) = @_;
+    my $ret = [];
+
+    for my $id ( @{ $zBBS->get_all_ids() } ) {
+        push @$ret, $zBBS->get( $id, $unijp, $zCategory );
+    }
+
+    return $ret;
+}
+
+sub all_with_page {
+    my ( $zBBS, $unijp, $zCategory, $item_per_page, $offset ) = @_;
+
+    require Data::Page;
+    my $entries = $zBBS->all( $unijp, $zCategory );
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
+sub get_all_ids {
+    my ($zBBS)   = @_;
     my $id_table = {};
-    my $ret      = [];
     my $iter     = $zBBS->get_common_repos()->iterate(
         sub {
             my ( $key, $value, $id_table ) = @_;
@@ -602,19 +612,7 @@ sub all {
         $id_table
     );
 
-    for my $id ( keys %$id_table ) {
-        push @$ret, $zBBS->get( $id, $unijp, $zCategory );
-    }
-    $ret;
-}
-
-sub all_with_page {
-    my ( $zBBS, $unijp, $zCategory, $item_per_page, $offset ) = @_;
-
-    require Data::Page;
-    my $entries = $zBBS->all( $unijp, $zCategory );
-    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
-    return ( [ $page->splice($entries) ], $page );
+    return [ keys %$id_table ];
 }
 
 sub _update_subject {
