@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Thread.pm 905 2007-07-18 13:32:09Z hikarin $
+# $Id: Thread.pm 1481 2007-10-24 14:13:30Z hikarin $
 #
 
 package Zeromin::Thread;
@@ -46,7 +46,6 @@ sub remove {
     my $bbs     = $zThread->{_bbs};
     my $key     = $zThread->{_key};
 
-    require Img0ch::BBS;
     require Zeromin::Plugin;
     require Zeromin::Upload;
     my $iBBS = Img0ch::BBS->new( $iKernel, { id => $bbs } );
@@ -55,19 +54,33 @@ sub remove {
 
     if ($range) {
         $option ||= { is_erase => 0, is_file_only => 0 };
-        if ( $option->{is_erase} ) {
-            require Img0ch::Log;
-            my $iLog = Img0ch::Log->new( $iBBS, $key );
-            my $plugin = $zPlugin->iterator( 'zeromin.erase.res', sub { } );
-            my $line = $zThread->{_line};
 
-            for my $resno ( @{$range} ) {
+        my $count = $zThread->count();
+        my $errno = 0;
+        my @tmp   = ();
+
+        $zThread->can_write( \$errno );
+        for my $resno (@$range) {
+            $resno < 2 and next;
+            ( $resno >= $count and ( $errno >= 1 and $errno <= 3 ) ) and next;
+            push @tmp, $resno;
+        }
+        @$range = @tmp;
+
+        if ( $option->{is_erase} ) {
+            my $iLog   = $iBBS->get_log_instance($key);
+            my $plugin = $zPlugin->iterator( 'zeromin.erase.res', sub { } );
+            my $line   = $zThread->{_line};
+
+            my @temp_range = @$range;
+            for my $resno (@temp_range) {
                 $resno = Img0ch::Kernel::intval($resno);
                 $resno < 2 and next;
                 splice @$line, ( $resno - 1 ), 1;
                 $plugin->($resno);
-                $iLog->remove($resno);
+                map { $_ = $_ - 1 } @temp_range;    ## no critic
             }
+
             $zUpload->remove($range);
             $zThread->save();
             @{ $zThread->{_line} } = @{$line};
@@ -83,18 +96,22 @@ sub remove {
             }
         }
         else {
-            require Img0ch::Setting;
-            my $iSetting = Img0ch::Setting->new($iBBS);
-            my $word     = $iSetting->get('BBS_DELETE_NAME')
+            require Img0ch::Thread::Revision;
+            my $iSetting = $option->{setting}
+                || $iBBS->get_setting_instance();
+            my $iTRevision = Img0ch::Thread::Revision->new( $iBBS, $key );
+            my $word = $iSetting->get('BBS_DELETE_NAME')
                 || pack( 'C*',
                 ( 0x82, 0xa0, 0x82, 0xda, 0x81, 0x5b, 0x82, 0xf1 ) );
             my $plugin = $zPlugin->iterator( 'zeromin.replace.res', sub { } );
             for my $resno ( @{$range} ) {
                 $resno = Img0ch::Kernel::intval($resno) || next;
+                $iTRevision->add( $resno, $zThread->get($resno) );
                 $zThread->set( [ $word, $word, $word, '', $word ], $resno );
                 $plugin->($resno);
             }
             $zUpload->remove($range);
+            $iTRevision->save();
             $zThread->save();
         }
     }
@@ -114,7 +131,29 @@ sub remove {
         @{ $zThread->{_line} } = ();
         $zThread->{_count} = 0;
     }
-    1;
+
+    return 1;
+}
+
+sub revert {
+    my ( $zThread, $range_and_rev ) = @_;
+    my $bbs = $zThread->{_bbs};
+    my $key = $zThread->{_key};
+
+    require Img0ch::Thread::Revision;
+    my $iTRevision = Img0ch::Thread::Revision->new(
+        Img0ch::BBS->new( $zThread->{_kernel}, { id => $bbs } ), $key );
+
+    while ( my ( $resno, $revision ) = each %$range_and_rev ) {
+        $resno = Img0ch::Kernel::intval($resno) || next;
+        $revision = Img0ch::Kernel::intval($revision);
+        my $content = $iTRevision->get( $resno, $revision );
+        $content->[4] or next;
+        $zThread->set( $content, $resno );
+    }
+    $zThread->save();
+
+    return 1;
 }
 
 sub stop {
@@ -146,18 +185,21 @@ sub stop {
     $zThread->save();
     $zThread->_plugin('zeromin.stop.thread');
 
-    1;
+    return 1;
 }
 
 sub restart {
     my ($zThread) = @_;
     my $errno = 0;
+
     $zThread->can_write( \$errno ) and return 0;
     $errno == 1 or return 0;
-    $zThread->remove( [ $zThread->count() ], { is_erase => 1 } );
+    splice @{ $zThread->{_line} }, ( $zThread->count() - 1 ), 1;
+    $zThread->{_count}--;
     $zThread->save();
     $zThread->_plugin('zeromin.restart.thread');
-    1;
+
+    return 1;
 }
 
 sub edit {
@@ -176,8 +218,17 @@ sub edit {
     defined $id or $id = $default->[3];
     my $comment = $set->[4];
     defined $comment or $comment = $default->[4];
+    my $subject = $set->[5];
+
+    require Img0ch::Thread::Revision;
+    my $iTRevision
+        = Img0ch::Thread::Revision->new(
+        Img0ch::BBS->new( $zThread->{_kernel}, { id => $zThread->{_bbs} } ),
+        $zThread->{_key} );
+    $iTRevision->add( $resno, $default );
+    $iTRevision->save();
+    $zThread->set( [ $from, $mail, $date, $id, $comment, $subject ], $resno );
 
-    $zThread->set( [ $from, $mail, $date, $id, $comment ], $resno );
     return 1;
 }
 
@@ -212,7 +263,7 @@ sub repair_upload_file_table {
 
     my $key = $zThread->{_key};
     $zUpload->set_key($key);
-    $zUpload->repair();
+    $zUpload->repair( $zThread->count() );
     $plugin_iterator->($key);
     return 1;
 }
@@ -223,7 +274,7 @@ sub import_from {
     my $iBBS = Img0ch::BBS->new( $iKernel, { id => $zThread->{_bbs} } );
     $detect_hint ||= $path;
 
-    require File::Copy;
+    defined $File::Copy::VERSION or require File::Copy;
     if ( $detect_hint =~ /\d{9,10}\.dat\z/xms ) {
         my $file = File::Basename::basename($detect_hint);
         my $dest = $iBBS->path( 'dat', $file );
@@ -235,8 +286,8 @@ sub import_from {
     elsif ($detect_hint =~ /\.tar\.gz\z/xms
         or $detect_hint =~ /\.tgz\z/xms )
     {
-        require Archive::Tar;
-        require File::Temp;
+        defined $Archive::Tar::VERSION or require Archive::Tar;
+        defined $File::Temp::VERSION   or require File::Temp;
         my $tar = Archive::Tar->new( $path, 1 )
             or $iKernel->throw_exception( Archive::Tar->error() );
         my $cwd = File::Temp::tempdir( CLEANUP => 1 );
@@ -254,10 +305,13 @@ sub import_from {
         }
         return 1;
     }
-    elsif ( eval "require Compress::Zlib; 1"
-        and $detect_hint =~ /\.zip/xms )
+    elsif (
+        $detect_hint =~ /\.zip/xms
+        and ( defined $Compress::Zlib::VERSION
+            or eval 'use Compress::Zlib qw(); 1' )
+        )
     {
-        require Archive::Zip;
+        defined $Archive::Zip::VERSION or require Archive::Zip;
         Archive::Zip::setErrorHandler(
             sub {
                 my $error = shift;
@@ -303,17 +357,14 @@ sub _strip_tags_from_dat {
     my ( $iKernel, $dest ) = @_;
     my $temp = "${dest}.tmp";
     eval {
-        local ( *RFH, *WFH, $! );
-        open *RFH, "<${dest}"    ## no critic
-            or $iKernel->throw_io_exception($dest);
-        open *WFH, ">${temp}"    ## no critic
-            or $iKernel->throw_io_exception($temp);
-        while ( my $line = <RFH> ) {
-            $line =~ s{</?a[^>]+>}{}gxms;
-            print {*WFH} $line or $iKernel->throw_io_exception($temp);
+        my $rfh = $iKernel->get_read_file_handle($dest);
+        my $wfh = $iKernel->get_write_file_handle($temp);
+        while ( my $line = <$rfh> ) {
+            $line =~ s{</?a[^>]*>}{}gxms;
+            print ${wfh} $line or $iKernel->throw_io_exception($temp);
         }
-        close *RFH or $iKernel->throw_io_exception($dest);
-        close *WFH or $iKernel->throw_io_exception($temp);
+        close $rfh or $iKernel->throw_io_exception($dest);
+        close $wfh or $iKernel->throw_io_exception($temp);
         rename $temp, $dest or $iKernel->throw_io_exception($dest);
     };
     if ( my $exception = $@ ) {
