@@ -14,39 +14,42 @@
 # *  limitations under the License.
 # */
 #
-# $Id: bbs.pm 1084 2007-09-08 15:27:51Z hikarin $
+# $Id: bbs.pm 1481 2007-10-24 14:13:30Z hikarin $
 #
 
 package Zeromin2::App::bbs;
 
 use strict;
 use Zeromin::BBS qw();
+use Zeromin2::App qw();
 
 BEGIN {
     Zeromin2::App->install_alias( __PACKAGE__,
         {   'repair_thread_upload_file_table' =>
                 [ 'thread', 'repair_upload_file_table' ],
-            'remove_thread'         => [ 'thread',  'remove' ],
-            'stop_thread'           => [ 'thread',  'stop' ],
-            'restart_thread'        => [ 'thread',  'restart' ],
-            'remove_res'            => [ 'thread',  'remove_res' ],
-            'erase_res'             => [ 'thread',  'erase_res' ],
-            'remove_file'           => [ 'thread',  'remove_file' ],
-            'edit_res_form'         => [ 'thread',  'edit_res_form' ],
-            'import_thread'         => [ 'thread',  'do_import' ],
-            'create_special_thread' => [ 'thread',  'create_special' ],
-            'freeze_file'           => [ 'upload',  'freeze_file' ],
-            'release_file'          => [ 'upload',  'release_file' ],
-            'pool_thread'           => [ 'pool',    'create' ],
-            'restore_pool'          => [ 'pool',    'restore' ],
-            'remove_pool'           => [ 'pool',    'remove' ],
-            'create_archive'        => [ 'archive', 'create' ],
-            'update_archive'        => [ 'archive', 'update' ],
-            'remove_archive'        => [ 'archive', 'remove' ],
-            'deny_ip_local'         => [ 'filter',  'deny_ip_local' ],
-            'deny_ip_global'        => [ 'filter',  'deny_ip_global' ],
-            'deny_serial_local'     => [ 'filter',  'deny_serial_local' ],
-            'deny_serial_global'    => [ 'filter',  'deny_serial_global' ],
+            'remove_thread'         => [ 'thread', 'remove' ],
+            'stop_thread'           => [ 'thread', 'stop' ],
+            'restart_thread'        => [ 'thread', 'restart' ],
+            'remove_res'            => [ 'thread', 'remove_res' ],
+            'erase_res'             => [ 'thread', 'erase_res' ],
+            'remove_file'           => [ 'thread', 'remove_file' ],
+            'edit_res_form'         => [ 'thread', 'edit_res_form' ],
+            'import_thread'         => [ 'thread', 'do_import' ],
+            'create_special_thread' => [ 'thread', 'create_special' ],
+            'update_removed_upload_files_as_json' =>
+                [ 'upload', 'update_removed_upload_files_as_json' ],
+            'freeze_file'        => [ 'upload',  'freeze_file' ],
+            'release_file'       => [ 'upload',  'release_file' ],
+            'pool_thread'        => [ 'pool',    'create' ],
+            'restore_pool'       => [ 'pool',    'restore' ],
+            'remove_pool'        => [ 'pool',    'remove' ],
+            'create_archive'     => [ 'archive', 'create' ],
+            'update_archive'     => [ 'archive', 'update' ],
+            'remove_archive'     => [ 'archive', 'remove' ],
+            'deny_ip_local'      => [ 'filter',  'deny_ip_local' ],
+            'deny_ip_global'     => [ 'filter',  'deny_ip_global' ],
+            'deny_serial_local'  => [ 'filter',  'deny_serial_local' ],
+            'deny_serial_global' => [ 'filter',  'deny_serial_global' ],
         }
     );
 }
@@ -86,7 +89,6 @@ sub load_index {
     my $iApp = Img0ch::App::BBS->new( $zApp->kernel(), $iRequest->request() );
     my ($param) = $iApp->update_index( $iBBS, 1, 1 );
 
-    require Img0ch::Log;
     require Img0ch::Thread::Revision;
     require Img0ch::Upload::Poll;
     require Zeromin2::Util;
@@ -95,7 +97,7 @@ sub load_index {
 
     for my $thread ( @{ $param->{Threads} } ) {
         my $key        = $thread->{key};
-        my $iLog       = Img0ch::Log->new( $iBBS, $key );
+        my $iLog       = $iBBS->get_log_instance($key);
         my $iTRevision = Img0ch::Thread::Revision->new( $iBBS, $key );
         my $iUPoll     = Img0ch::Upload::Poll->new( $iBBS, $key );
         for my $res ( @{ $thread->{Thread} } ) {
@@ -127,10 +129,13 @@ sub load_index {
     $rewriter->( \$param->{Banner} );
     $rewriter->( \$param->{SubBanner} );
 
+    my $iSetting = $iApp->setting();
     $zApp->add_template_param(
-        {   %{ $iApp->setting()->get_hash() },
+        {   %{ $iSetting->get_hash() },
             %$param,
-            BBSName => $iBBS->get_name()
+            BBSName => $iBBS->get_name(),
+            IsTypeTemplate =>
+                ( $iSetting->get('BBS_TEMPLATE') =~ /\Atype/xms ? 1 : 0 ),
         }
     );
     $zApp->encoding('Shift_JIS');
@@ -178,7 +183,6 @@ sub _load_threads {
     my ( $unijp, $encoding ) = $zApp->unijp();
     $zSubject->load();
 
-    require Img0ch::Log;
     require Zeromin2::Util;
     my $log_privilege = $zApp->privilege('can_view_thread_log');
     my $now           = time();
@@ -193,7 +197,7 @@ sub _load_threads {
         my $speed  = $count / $elapse * 86400;
         $speed < 0.05 and $speed = 0.1;
         if ($log_privilege) {
-            my $iLog = Img0ch::Log->new( $iBBS, $key );
+            my $iLog = $iBBS->get_log_instance($key);
             my $info = $iLog->get(1);
             $agent = $info->[3];
             if ( my $serial = $info->[2] ) {
@@ -429,10 +433,9 @@ sub _task3 {
     $zApp->check_csrf()          or return $zApp->return_value(1);
     $zApp->privilege($priv_meth) or return $zApp->return_value(1);
 
-    my $zUser    = $zApp->user();
-    my $iKernel  = $zApp->kernel();
-    my $iRequest = $zApp->request();
-    my @param    = $iRequest->param('board');
+    my $zUser   = $zApp->user();
+    my $iKernel = $zApp->kernel();
+    my @param   = $zApp->request()->param('board');
     scalar @param or return $zApp->return_value(2);
 
     require Zeromin::Setting;
